@@ -3,11 +3,11 @@
 *                     U n d o a b l e   C o m m a n d s                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This program is free software; you can redistribute it and/or modify          *
+* This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
-* the Free Software Foundation; either version 2 of the License, or             *
+* the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
@@ -16,16 +16,11 @@
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
-* along with this program; if not, write to the Free Software                   *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: Commands.cpp,v 1.18 2006/01/22 18:01:10 fox Exp $                        *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ********************************************************************************/
 #include "fx.h"
 #include "Commands.h"
-#include "FXRex.h"
-#include "FXArray.h"
-#include "Hilite.h"
+#include "Syntax.h"
 #include "TextWindow.h"
 #include "Adie.h"
 
@@ -56,14 +51,14 @@ FXIMPLEMENT_ABSTRACT(FXTextInsert,FXTextCommand,NULL,0)
 
 // Insert command
 FXTextInsert::FXTextInsert(FXText* txt,FXint p,FXint ni,const FXchar* ins):FXTextCommand(txt,p,0,ni){
-  FXMALLOC(&buffer,FXchar,ni);
+  allocElms(buffer,ni);
   memcpy(buffer,ins,ni);
   }
 
 
 // Undo an insert removes the inserted text
 void FXTextInsert::undo(){
-  text->removeText(pos,nins,TRUE);
+  text->removeText(pos,nins,true);
   text->setCursorPos(pos);
   text->makePositionVisible(pos);
   }
@@ -71,7 +66,7 @@ void FXTextInsert::undo(){
 
 // Redo an insert inserts the same old text again
 void FXTextInsert::redo(){
-  text->insertText(pos,buffer,nins,TRUE);
+  text->insertText(pos,buffer,nins,true);
   text->setCursorPos(pos+nins);
   text->makePositionVisible(pos+nins);
   }
@@ -81,14 +76,14 @@ FXIMPLEMENT_ABSTRACT(FXTextDelete,FXTextCommand,NULL,0)
 
 // Delete command
 FXTextDelete::FXTextDelete(FXText* txt,FXint p,FXint nd,const FXchar* del):FXTextCommand(txt,p,nd,0){
-  FXMALLOC(&buffer,FXchar,nd);
+  allocElms(buffer,nd);
   memcpy(buffer,del,nd);
   }
 
 
 // Undo a delete reinserts the old text
 void FXTextDelete::undo(){
-  text->insertText(pos,buffer,ndel,TRUE);
+  text->insertText(pos,buffer,ndel,true);
   text->setCursorPos(pos+ndel);
   text->makePositionVisible(pos+ndel);
   }
@@ -96,7 +91,7 @@ void FXTextDelete::undo(){
 
 // Redo a delete removes it again
 void FXTextDelete::redo(){
-  text->removeText(pos,ndel,TRUE);
+  text->removeText(pos,ndel,true);
   text->setCursorPos(pos);
   text->makePositionVisible(pos);
   }
@@ -106,7 +101,7 @@ FXIMPLEMENT_ABSTRACT(FXTextReplace,FXTextCommand,NULL,0)
 
 // Replace command
 FXTextReplace::FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni,const FXchar* del,const FXchar* ins):FXTextCommand(txt,p,nd,ni){
-  FXMALLOC(&buffer,FXchar,nd+ni);
+  allocElms(buffer,nd+ni);
   memcpy(buffer,del,nd);
   memcpy(buffer+nd,ins,ni);
   }
@@ -114,7 +109,7 @@ FXTextReplace::FXTextReplace(FXText* txt,FXint p,FXint nd,FXint ni,const FXchar*
 
 // Undo a replace reinserts the old text
 void FXTextReplace::undo(){
-  text->replaceText(pos,nins,buffer,ndel,TRUE);
+  text->replaceText(pos,nins,buffer,ndel,true);
   text->setCursorPos(pos+ndel);
   text->makePositionVisible(pos+ndel);
   }
@@ -122,7 +117,7 @@ void FXTextReplace::undo(){
 
 // Redo a replace reinserts the new text
 void FXTextReplace::redo(){
-  text->replaceText(pos,ndel,buffer+ndel,nins,TRUE);
+  text->replaceText(pos,ndel,buffer+ndel,nins,true);
   text->setCursorPos(pos+nins);
   text->makePositionVisible(pos+nins);
   }
