@@ -3,11 +3,11 @@
 *                        P r e f e r e n c e s   D i a l o g                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This program is free software; you can redistribute it and/or modify          *
+* This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
-* the Free Software Foundation; either version 2 of the License, or             *
+* the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
@@ -16,33 +16,30 @@
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
-* along with this program; if not, write to the Free Software                   *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: Preferences.h,v 1.31 2006/01/22 18:01:11 fox Exp $                       *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ********************************************************************************/
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
 
 
-//////////////////////////////  UNDER DEVELOPMENT  //////////////////////////////
-
 
 class TextWindow;
 class Adie;
-class FXSyntax;
+class Syntax;
 
 
 class Preferences : public FXDialogBox {
   FXDECLARE(Preferences)
 protected:
   FXText          *filepattext;
-  FXList          *stylelist;
-  FXTextField     *stylename;
+  FXMatrix        *stylemat;
+  FXTextField     *searchtext;
+  FXTextField     *syntaxtext;
   FXIcon          *pal;
   FXIcon          *ind;
   FXIcon          *pat;
   FXIcon          *sty;
+  FXIcon          *mis;
 private:
   Preferences(){}
   Preferences(const Preferences&);
@@ -62,7 +59,7 @@ public:
   FXString getPatterns() const;
 
   // Set language syntax
-  void setSyntax(FXSyntax* syn);
+  void setSyntax(Syntax* syn);
 
     // Clean up
   virtual ~Preferences();
