@@ -3,11 +3,11 @@
 *                     T h e   A d i e   T e x t   E d i t o r                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This program is free software; you can redistribute it and/or modify          *
+* This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
-* the Free Software Foundation; either version 2 of the License, or             *
+* the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
@@ -16,20 +16,18 @@
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
-* along with this program; if not, write to the Free Software                   *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: TextWindow.h,v 1.38 2006/02/06 03:03:40 fox Exp $                        *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ********************************************************************************/
 #ifndef TEXTWINDOW_H
 #define TEXTWINDOW_H
 
 
 
+class Adie;
+class Syntax;
 class HelpWindow;
 class Preferences;
-class Adie;
-class FXSyntax;
+class ShellCommand;
 
 // Array of styles
 typedef FXArray<FXHiliteStyle> FXHiliteArray;
@@ -41,6 +39,7 @@ class TextWindow : public FXMainWindow {
 protected:
   FXToolBarShell      *dragshell1;              // Shell for floating menubar
   FXToolBarShell      *dragshell2;              // Shell for floating toolbar
+  FXToolBarShell      *dragshell3;              // Shell for floating search bar
   FXDockSite          *topdock;                 // Topmost dock area
   FXDockSite          *bottomdock;              // Bottom dock area
   FXDockSite          *leftdock;                // Left dock area
@@ -49,41 +48,65 @@ protected:
   FXMenuPane          *editmenu;                // Edit menu
   FXMenuPane          *gotomenu;                // Goto menu
   FXMenuPane          *searchmenu;              // Search menu
+  FXMenuPane          *shellmenu;               // Shell menu
   FXMenuPane          *optionmenu;              // Option menu
   FXMenuPane          *viewmenu;                // View menu
   FXMenuPane          *windowmenu;              // Window menu
   FXMenuPane          *helpmenu;                // Help menu
-  FXMenuPane          *popupmenu;               // Popup menu
   FXMenuPane          *syntaxmenu;              // Syntax menu
+  FXMenuPane          *tabsmenu;                // Tab selection menu
   FXVerticalFrame     *treebox;                 // Tree box containing directories/files
   FXHorizontalFrame   *undoredoblock;           // Undo/redo block on status line
-  FXText              *editor;                  // Multiline text widget
+  FXHorizontalFrame   *editorframe;             // Editor frame
+  FXHorizontalFrame   *loggerframe;             // Logger frame
+  FXText              *editor;                  // Editor text widget
+  FXText              *logger;                  // Logger text widget
   FXDirList           *dirlist;                 // Directory view
   FXComboBox          *filter;                  // Combobox for pattern list
   FXTextField         *clock;                   // Time
   FXMenuBar           *menubar;                 // Menu bar
   FXToolBar           *toolbar;                 // Tool bar
+  FXToolBar           *searchbar;               // Incremental search bar
+  FXTextField         *searchtext;              // Incremental search text field
   FXStatusBar         *statusbar;               // Status bar
   FXFont              *font;                    // Text window font
   FXint                bookmark[10];            // Book marks
-  FXSyntax            *syntax;                  // Syntax highlighter
+  Syntax              *syntax;                  // Syntax highlighter
   FXUndoList           undolist;                // Undo list
   FXRecentFiles        mrufiles;                // Recent files list
   FXString             filename;                // File being edited
   FXTime               filetime;                // Original modtime of file
   FXbool               filenameset;             // Filename is set
   FXString             delimiters;              // Text delimiters
-  FXString             searchpath;              // To search for files
+  FXString             searchpaths;             // Search paths for files
   FXHiliteArray        styles;                  // Highlight styles
-  FXint                currentstyle;            // Style being changed
+  ShellCommand        *shellCommand;            // Running shell command, if any
+  FXint                replaceStart;            // Start of text to be replaced
+  FXint                replaceEnd;              // End of text to be replaced
+  FXint                initialwidth;            // Initial width
+  FXint                initialheight;           // Initial height
+  FXString             searchstring;            // String of last search
+  FXuint               searchflags;             // Incremental search flags
+  FXint                searchpos;               // Incremental search position
+  FXbool               searching;               // Incremental search in effect
+  FXbool               showsearchbar;           // Showing incremental search bar
+  FXbool               showlogger;              // Showing error logger
+  FXbool               initialsize;             // New window is initialwidth x initialheight
   FXbool               colorize;                // Syntax coloring on if possible
   FXbool               stripcr;                 // Strip carriage returns
   FXbool               stripsp;                 // Strip trailing spaces
+  FXbool               appendcr;                // Append carriage returns
   FXbool               appendnl;                // Append missing newline at end of text
   FXbool               saveviews;               // Save views of files
   FXbool               savemarks;               // Save bookmarks of files
   FXbool               warnchanged;             // Warn if changed by other program
+  FXbool               lastfilesize;            // Keep window size for each file
+  FXbool               lastfileposition;        // Keep window position for each file
 protected:
+  void createMenubar();
+  void createToolbar();
+  void createSearchbar();
+  void createStatusbar();
   void readRegistry();
   void writeRegistry();
   FXString unique() const;
@@ -95,8 +118,9 @@ protected:
   void restyleText();
   void restyleText(FXint pos,FXint del,FXint ins);
   FXint restyleRange(FXint beg,FXint end,FXint& head,FXint& tail,FXint rule);
-  FXHiliteStyle readStyleForRule(const FXString& name);
-  void writeStyleForRule(const FXString& name,const FXHiliteStyle& style);
+  FXHiliteStyle readStyleForRule(const FXString& group,const FXString& name,const FXString& style);
+  void writeStyleForRule(const FXString& group,const FXString& name,const FXHiliteStyle& style);
+  FXbool matchesSelection(const FXString& string,FXint* beg,FXint* end,FXuint flgs,FXint npar) const;
 protected:
   enum{
     MAXUNDOSIZE    = 1000000,               // Don't let the undo buffer get out of hand
@@ -111,6 +135,7 @@ public:
   long onFocusIn(FXObject*,FXSelector,void*);
   long onCmdAbout(FXObject*,FXSelector,void*);
   long onCmdHelp(FXObject*,FXSelector,void*);
+  long onUpdIsEditable(FXObject*,FXSelector,void*);
 
   // File management
   long onCmdNew(FXObject*,FXSelector,void*);
@@ -125,6 +150,7 @@ public:
   long onCmdSaveAs(FXObject*,FXSelector,void*);
   long onCmdFont(FXObject*,FXSelector,void*);
   long onCmdPrint(FXObject*,FXSelector,void*);
+  long onCmdFindInFiles(FXObject*,FXSelector,void*);
   long onCmdSaveSettings(FXObject*,FXSelector,void*);
 
   // Text display
@@ -164,6 +190,8 @@ public:
   long onUpdLineNumbers(FXObject*,FXSelector,void*);
   long onCmdTabColumns(FXObject*,FXSelector,void*);
   long onUpdTabColumns(FXObject*,FXSelector,void*);
+  long onCmdTabSelect(FXObject*,FXSelector,void*);
+  long onUpdTabSelect(FXObject*,FXSelector,void*);
   long onCmdBraceMatch(FXObject*,FXSelector,void*);
   long onUpdBraceMatch(FXObject*,FXSelector,void*);
   long onCmdAutoIndent(FXObject*,FXSelector,void*);
@@ -178,13 +206,13 @@ public:
   long onUpdWrap(FXObject*,FXSelector,void*);
 
   // Text changes
+  long onTextFocus(FXObject*,FXSelector,void*);
   long onTextInserted(FXObject*,FXSelector,void*);
   long onTextReplaced(FXObject*,FXSelector,void*);
   long onTextDeleted(FXObject*,FXSelector,void*);
+  long onTextDNDDrop(FXObject*,FXSelector,void*);
+  long onTextDNDMotion(FXObject*,FXSelector,void*);
   long onTextRightMouse(FXObject*,FXSelector,void*);
-  long onTextChanged(FXObject*,FXSelector,void*);
-  long onEditDNDMotion(FXObject*,FXSelector,void*);
-  long onEditDNDDrop(FXObject*,FXSelector,void*);
 
   // Miscellaneous
   long onCmdStripReturns(FXObject*,FXSelector,void*);
@@ -193,17 +221,18 @@ public:
   long onUpdStripSpaces(FXObject*,FXSelector,void*);
   long onCmdAppendNewline(FXObject*,FXSelector,void*);
   long onUpdAppendNewline(FXObject*,FXSelector,void*);
-  long onCmdIncludePaths(FXObject*,FXSelector,void*);
+  long onCmdAppendCarriageReturn(FXObject*,FXSelector,void*);
+  long onUpdAppendCarriageReturn(FXObject*,FXSelector,void*);
   long onCmdFilter(FXObject*,FXSelector,void*);
   long onUpdOverstrike(FXObject*,FXSelector,void*);
   long onUpdReadOnly(FXObject*,FXSelector,void*);
+  long onUpdTabMode(FXObject*,FXSelector,void*);
   long onUpdNumRows(FXObject*,FXSelector,void*);
   long onClock(FXObject*,FXSelector,void*);
   long onCmdPreferences(FXObject*,FXSelector,void*);
   long onCmdDelimiters(FXObject*,FXSelector,void*);
   long onUpdDelimiters(FXObject*,FXSelector,void*);
   long onCmdInsertFile(FXObject*,FXSelector,void*);
-  long onUpdInsertFile(FXObject*,FXSelector,void*);
   long onCmdExtractFile(FXObject*,FXSelector,void*);
   long onUpdExtractFile(FXObject*,FXSelector,void*);
   long onCmdWheelAdjust(FXObject*,FXSelector,void*);
@@ -214,6 +243,8 @@ public:
   long onUpdPrevMark(FXObject*,FXSelector,void*);
   long onCmdSetMark(FXObject*,FXSelector,void*);
   long onUpdSetMark(FXObject*,FXSelector,void*);
+  long onCmdGotoMark(FXObject*,FXSelector,void*);
+  long onUpdGotoMark(FXObject*,FXSelector,void*);
   long onCmdClearMarks(FXObject*,FXSelector,void*);
   long onCmdSaveMarks(FXObject*,FXSelector,void*);
   long onUpdSaveMarks(FXObject*,FXSelector,void*);
@@ -231,12 +262,76 @@ public:
   long onUpdWindow(FXObject*,FXSelector,void*);
   long onCmdSyntaxSwitch(FXObject*,FXSelector,void*);
   long onUpdSyntaxSwitch(FXObject*,FXSelector,void*);
-  long onCmdStyleFlags(FXObject*,FXSelector,void*);
-  long onUpdStyleFlags(FXObject*,FXSelector,void*);
-  long onCmdStyleColor(FXObject*,FXSelector,void*);
-  long onUpdStyleColor(FXObject*,FXSelector,void*);
-  long onCmdStyleIndex(FXObject*,FXSelector,void*);
-  long onUpdStyleIndex(FXObject*,FXSelector,void*);
+  long onCmdUseInitialSize(FXObject*,FXSelector,void*);
+  long onUpdUseInitialSize(FXObject*,FXSelector,void*);
+  long onCmdSetInitialSize(FXObject*,FXSelector,void*);
+  long onCmdToggleBrowser(FXObject*,FXSelector,void*);
+  long onUpdToggleBrowser(FXObject*,FXSelector,void*);
+  long onCmdSearchPaths(FXObject*,FXSelector,void*);
+  long onUpdSearchPaths(FXObject*,FXSelector,void*);
+
+  // Shell commands
+  long onCmdShellDialog(FXObject*,FXSelector,void*);
+  long onUpdShellDialog(FXObject*,FXSelector,void*);
+  long onCmdShellFilter(FXObject*,FXSelector,void*);
+  long onUpdShellFilter(FXObject*,FXSelector,void*);
+  long onCmdShellCancel(FXObject*,FXSelector,void*);
+  long onUpdShellCancel(FXObject*,FXSelector,void*);
+  long onCmdShellOutput(FXObject*,FXSelector,void*);
+  long onCmdShellError(FXObject*,FXSelector,void*);
+  long onCmdShellDone(FXObject*,FXSelector,void*);
+
+  // Evaluate expression
+  long onCmdExpression(FXObject*,FXSelector,void*);
+  long onUpdExpression(FXObject*,FXSelector,void*);
+
+  // URL encode/decode
+  long onCmdURLEncode(FXObject*,FXSelector,void*);
+  long onCmdURLDecode(FXObject*,FXSelector,void*);
+  long onUpdURLCoding(FXObject*,FXSelector,void*);
+
+  // Jumping around
+  long onCmdGotoLine(FXObject*,FXSelector,void*);
+  long onCmdGotoSelected(FXObject*,FXSelector,void*);
+
+  // Search
+  long onCmdSearch(FXObject*,FXSelector,void*);
+  long onCmdReplace(FXObject*,FXSelector,void*);
+  long onCmdSearchSel(FXObject*,FXSelector,void*);
+  long onCmdSearchNext(FXObject*,FXSelector,void*);
+
+  // Incremental search
+  long onChgISearchText(FXObject*,FXSelector,void*);
+  long onCmdISearchText(FXObject*,FXSelector,void*);
+  long onKeyISearchText(FXObject*,FXSelector,void*);
+  long onCmdISearchPrev(FXObject*,FXSelector,void*);
+  long onCmdISearchNext(FXObject*,FXSelector,void*);
+  long onCmdISearchStart(FXObject*,FXSelector,void*);
+  long onCmdISearchFinish(FXObject*,FXSelector,void*);
+  long onUpdISearchModifiers(FXObject*,FXSelector,void*);
+  long onCmdISearchModifiers(FXObject*,FXSelector,void*);
+
+  // Style changes
+  long onCmdStyleNormalFG(FXObject*,FXSelector,void*);
+  long onUpdStyleNormalFG(FXObject*,FXSelector,void*);
+  long onCmdStyleNormalBG(FXObject*,FXSelector,void*);
+  long onUpdStyleNormalBG(FXObject*,FXSelector,void*);
+  long onCmdStyleSelectFG(FXObject*,FXSelector,void*);
+  long onUpdStyleSelectFG(FXObject*,FXSelector,void*);
+  long onCmdStyleSelectBG(FXObject*,FXSelector,void*);
+  long onUpdStyleSelectBG(FXObject*,FXSelector,void*);
+  long onCmdStyleHiliteFG(FXObject*,FXSelector,void*);
+  long onUpdStyleHiliteFG(FXObject*,FXSelector,void*);
+  long onCmdStyleHiliteBG(FXObject*,FXSelector,void*);
+  long onUpdStyleHiliteBG(FXObject*,FXSelector,void*);
+  long onCmdStyleActiveBG(FXObject*,FXSelector,void*);
+  long onUpdStyleActiveBG(FXObject*,FXSelector,void*);
+  long onCmdStyleUnderline(FXObject*,FXSelector,void*);
+  long onUpdStyleUnderline(FXObject*,FXSelector,void*);
+  long onCmdStyleStrikeout(FXObject*,FXSelector,void*);
+  long onUpdStyleStrikeout(FXObject*,FXSelector,void*);
+  long onCmdStyleBold(FXObject*,FXSelector,void*);
+  long onUpdStyleBold(FXObject*,FXSelector,void*);
 public:
   enum{
     ID_ABOUT=FXMainWindow::ID_LAST,
@@ -251,6 +346,7 @@ public:
     ID_SAVEAS,
     ID_FONT,
     ID_HELP,
+    ID_FINDFILES,
     ID_WINDOW,
     ID_PRINT,
     ID_TEXT_BACK,
@@ -273,12 +369,14 @@ public:
     ID_FIXED_WRAP,
     ID_SAVE_SETTINGS,
     ID_TEXT,
+    ID_LOGGER,
     ID_STRIP_CR,
     ID_STRIP_SP,
     ID_APPEND_NL,
-    ID_INCLUDE_PATH,
+    ID_APPEND_CR,
     ID_OVERSTRIKE,
     ID_READONLY,
+    ID_TABMODE,
     ID_CLOCKTIME,
     ID_PREFERENCES,
     ID_TABCOLUMNS,
@@ -295,6 +393,16 @@ public:
     ID_NEXT_MARK,
     ID_PREV_MARK,
     ID_CLEAR_MARKS,
+    ID_MARK_0,
+    ID_MARK_1,
+    ID_MARK_2,
+    ID_MARK_3,
+    ID_MARK_4,
+    ID_MARK_5,
+    ID_MARK_6,
+    ID_MARK_7,
+    ID_MARK_8,
+    ID_MARK_9,
     ID_SAVEMARKS,
     ID_SAVEVIEWS,
     ID_SHOWACTIVE,
@@ -314,23 +422,69 @@ public:
     ID_WINDOW_10,
     ID_SYNTAX_FIRST,
     ID_SYNTAX_LAST=ID_SYNTAX_FIRST+100,
-    ID_STYLE_INDEX,
-    ID_STYLE_NORMAL_FG,
-    ID_STYLE_NORMAL_BG,
-    ID_STYLE_SELECT_FG,
-    ID_STYLE_SELECT_BG,
-    ID_STYLE_HILITE_FG,
-    ID_STYLE_HILITE_BG,
-    ID_STYLE_ACTIVE_BG,
-    ID_STYLE_UNDERLINE,
-    ID_STYLE_STRIKEOUT,
-    ID_STYLE_BOLD,
+    ID_STYLE_NORMAL_FG_FIRST,
+    ID_STYLE_NORMAL_FG_LAST=ID_STYLE_NORMAL_FG_FIRST+100,
+    ID_STYLE_NORMAL_BG_FIRST,
+    ID_STYLE_NORMAL_BG_LAST=ID_STYLE_NORMAL_BG_FIRST+100,
+    ID_STYLE_SELECT_FG_FIRST,
+    ID_STYLE_SELECT_FG_LAST=ID_STYLE_SELECT_FG_FIRST+100,
+    ID_STYLE_SELECT_BG_FIRST,
+    ID_STYLE_SELECT_BG_LAST=ID_STYLE_SELECT_BG_FIRST+100,
+    ID_STYLE_HILITE_FG_FIRST,
+    ID_STYLE_HILITE_FG_LAST=ID_STYLE_HILITE_FG_FIRST+100,
+    ID_STYLE_HILITE_BG_FIRST,
+    ID_STYLE_HILITE_BG_LAST=ID_STYLE_HILITE_BG_FIRST+100,
+    ID_STYLE_ACTIVE_BG_FIRST,
+    ID_STYLE_ACTIVE_BG_LAST=ID_STYLE_ACTIVE_BG_FIRST+100,
+    ID_STYLE_UNDERLINE_FIRST,
+    ID_STYLE_UNDERLINE_LAST=ID_STYLE_UNDERLINE_FIRST+100,
+    ID_STYLE_STRIKEOUT_FIRST,
+    ID_STYLE_STRIKEOUT_LAST=ID_STYLE_STRIKEOUT_FIRST+100,
+    ID_STYLE_BOLD_FIRST,
+    ID_STYLE_BOLD_LAST=ID_STYLE_BOLD_FIRST+100,
+    ID_USE_INITIAL_SIZE,
+    ID_SET_INITIAL_SIZE,
+    ID_TOGGLE_BROWSER,
+    ID_SEARCHPATHS,
+    ID_EXPRESSION,
+    ID_GOTO_LINE,
+    ID_GOTO_SELECTED,
+    ID_SEARCH,
+    ID_REPLACE,
+    ID_SEARCH_SEL_FORW,
+    ID_SEARCH_SEL_BACK,
+    ID_SEARCH_NXT_FORW,
+    ID_SEARCH_NXT_BACK,
+    ID_ISEARCH_TEXT,
+    ID_ISEARCH_REVERSE,
+    ID_ISEARCH_IGNCASE,
+    ID_ISEARCH_REGEX,
+    ID_ISEARCH_PREV,
+    ID_ISEARCH_NEXT,
+    ID_ISEARCH_START,
+    ID_ISEARCH_FINISH,
+    ID_TABSELECT_1,
+    ID_TABSELECT_2,
+    ID_TABSELECT_3,
+    ID_TABSELECT_4,
+    ID_TABSELECT_5,
+    ID_TABSELECT_6,
+    ID_TABSELECT_7,
+    ID_TABSELECT_8,
+    ID_SHELL_DIALOG,
+    ID_SHELL_FILTER,
+    ID_SHELL_CANCEL,
+    ID_SHELL_OUTPUT,
+    ID_SHELL_ERROR,
+    ID_SHELL_DONE,
+    ID_URL_ENCODE,
+    ID_URL_DECODE,
     ID_LAST
     };
 public:
 
   // Create new text window
-  TextWindow(Adie* a,const FXString& file);
+  TextWindow(Adie* a);
 
   // Create window
   virtual void create();
@@ -338,26 +492,41 @@ public:
   // Detach window
   virtual void detach();
 
-  // Close the window, return TRUE if actually closed
-  virtual FXbool close(FXbool notify=FALSE);
+  // Close the window, return true if actually closed
+  virtual FXbool close(FXbool notify=false);
 
   // Return Adie application
   Adie* getApp() const { return (Adie*)FXMainWindow::getApp(); }
 
+  // Set current file of directory browser
+  void setBrowserCurrentFile(const FXString& file);
+
+  // Get current file of directory browser
+  FXString getBrowserCurrentFile() const;
+
   // Return this window's filename
   const FXString& getFilename() const { return filename; }
 
   // Change this window's filename
   void setFilename(const FXString& file){ filename=file; }
 
-  // Has a filename been set or is it a new window
+  // Change file time
+  void setFiletime(FXTime t){ filetime=t; }
+
+  // Get file time
+  FXTime getFiletime() const { return filetime; }
+
+  // Set filename is set flag
+  void setFilenameSet(FXbool set){ filenameset=set; }
+
+  // Has a filename been set
   FXbool isFilenameSet() const { return filenameset; }
 
   // Is it modified
   FXbool isModified() const;
 
   // Set editable flag
-  void setEditable(FXbool edit=TRUE);
+  void setEditable(FXbool edit=true);
 
   // Is it editable
   FXbool isEditable() const;
@@ -374,7 +543,7 @@ public:
   // Extract selection to file
   FXbool extractFile(const FXString& file);
 
-  // Return TRUE if changes have been saved
+  // Return true if changes have been saved
   FXbool saveChanges();
 
   // Change pattern list
@@ -383,21 +552,30 @@ public:
   // Get pattern list
   FXString getPatterns() const;
 
+  // Set search paths
+  void setSearchPaths(const FXString& paths);
+
+  // Get search paths
+  FXString getSearchPaths() const;
+
   // Change current file pattern
   void setCurrentPattern(FXint n);
 
   // Return current file pattern
   FXint getCurrentPattern() const;
 
-  // Add bookmark at current cursor position
+  // Goto position
+  void gotoPosition(FXint pos);
+
+  // Add bookmark at given position pos
   void setBookmark(FXint pos);
 
+  // Remove bookmark at given position pos
+  void clearBookmark(FXint pos);
+
   // Update bookmarks upon a text mutation
   void updateBookmarks(FXint pos,FXint nd,FXint ni);
 
-  // Goto bookmark
-  void gotoBookmark(FXint b);
-
   // Clear bookmarks
   void clearBookmarks();
 
@@ -405,33 +583,42 @@ public:
   void readBookmarks(const FXString& file);
   void writeBookmarks(const FXString& file);
 
-  // Visit given line
-  void visitLine(FXint line);
+  // Visit given line, and column
+  void visitLine(FXint line,FXint column=0);
 
   // Read/write view
   void readView(const FXString& file);
   void writeView(const FXString& file);
 
+  // Start incremental search
+  void startISearch();
+
+  // Finish incremental search
+  void finishISearch();
+
+  // Search next incremental text
+  FXbool performISearch(const FXString& text,FXbool advance=false,FXbool notify=false);
+
+  // Start shell command
+  FXbool startCommand(const FXString& command,const FXString& input=FXString::null);
+
+  // Done with command
+  FXbool doneCommand();
+
+  // Stop shell command
+  FXbool stopCommand();
+
   // Set syntax
-  void setSyntax(FXSyntax* syn);
+  void setSyntax(Syntax* syn);
 
   // Get syntax
-  FXSyntax* getSyntax() const { return syntax; }
+  Syntax* getSyntax() const { return syntax; }
 
   // Determine syntax
   void determineSyntax();
 
-  // Set syntax by name
-  FXbool forceSyntax(const FXString& language);
-
-  // Change style colors
-  void setStyleColors(FXint index,const FXHiliteStyle& style);
-
-  // Get style colors
-  const FXHiliteStyle& getStyleColors(FXint index) const { return styles[index]; }
-
-  // Redraw when style changed
-  void redraw();
+  // Set status message
+  void setStatusMessage(const FXString& msg);
 
   // Delete text window
   virtual ~TextWindow();
@@ -441,4 +628,3 @@ public:
 typedef FXObjectListOf<TextWindow> TextWindowList;
 
 #endif
-
