@@ -3,11 +3,11 @@
 *                  F O X   D e s k t o p   C a l c u l a t o r                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2001,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This program is free software; you can redistribute it and/or modify          *
+* This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
-* the Free Software Foundation; either version 2 of the License, or             *
+* the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
@@ -16,10 +16,7 @@
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
-* along with this program; if not, write to the Free Software                   *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: Calculator.cpp,v 1.58 2006/01/22 18:01:12 fox Exp $                      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ********************************************************************************/
 #include "fx.h"
 #include "fxkeys.h"
@@ -31,6 +28,7 @@
 #include <unistd.h>
 #endif
 #include <ctype.h>
+#include <math.h>
 #include "icons.h"
 #include "Calculator.h"
 #include "Preferences.h"
@@ -162,7 +160,7 @@ static const FXuint   nanny[2]={0xffffffff,0x7fffffff};
 #endif
 
 // Double precision nan
-static const FXdouble& dblnan=*((FXdouble*)nanny);
+static const FXdouble& dblnan=*((const FXdouble*)(const void*)nanny);
 
 
 // Operator priorities
@@ -379,8 +377,8 @@ Calculator::Calculator(FXApp* a):FXMainWindow(a,"FOX Calculator",NULL,NULL,DECOR
   base=NUM_DEC;
   angles=ANG_RAD;
   precision=16;
-  exponent=MAYBE;
-  beep=TRUE;
+  exponent=EXPONENT_IFNEEDED;
+  beep=true;
   parens=0;
   modifiers=0;
   }
@@ -622,8 +620,8 @@ FXColor Calculator::getAngleColor() const {
 
 
 // Set display font
-void Calculator::setDisplayFont(FXFont* font){
-  display->setFont(font);
+void Calculator::setDisplayFont(FXFont* fnt){
+  display->setFont(fnt);
   }
 
 
@@ -659,19 +657,19 @@ void Calculator::readRegistry(){
   FXColor angmodeclr=getApp()->reg().readColorEntry("SETTINGS","anglemodecolor",FXRGB(203,203,203));
 
   // Number base
-  FXint numbase=getApp()->reg().readIntEntry("SETTINGS","base",NUM_DEC);
+  FXint nbase=getApp()->reg().readIntEntry("SETTINGS","base",NUM_DEC);
 
   // Angle type
-  FXint angmode=getApp()->reg().readIntEntry("SETTINGS","angles",ANG_RAD);
+  FXint amode=getApp()->reg().readIntEntry("SETTINGS","angles",ANG_RAD);
 
   // Exponent mode
-  FXbool expmode=(FXExponent)getApp()->reg().readIntEntry("SETTINGS","exponent",MAYBE);
+  FXint expmode=(FXExponent)getApp()->reg().readIntEntry("SETTINGS","exponent",EXPONENT_IFNEEDED);
 
   // Precision
   FXint prec=getApp()->reg().readIntEntry("SETTINGS","precision",10);
 
   // Beep
-  FXbool noise=getApp()->reg().readIntEntry("SETTINGS","beep",TRUE);
+  FXbool noise=getApp()->reg().readIntEntry("SETTINGS","beep",true);
 
   // Memory cell
   recall=getApp()->reg().readRealEntry("SETTINGS","memory",0.0);
@@ -698,8 +696,8 @@ void Calculator::readRegistry(){
   setAngleColor(angmodeclr);
 
   // Number base
-  setBase(numbase);
-  setAngles(angmode);
+  setBase(nbase);
+  setAngles(amode);
   setPrecision(prec);
   setExponentMode(expmode);
   setBeep(noise);
@@ -778,9 +776,9 @@ void Calculator::setDisplayText(const FXString& txt){
 FXdouble Calculator::getDisplayValue() const {
   FXdouble val;
   if(base==10)
-    val=FXDoubleVal(getDisplayText());
+    val=getDisplayText().toDouble();
   else
-    val=(FXdouble)FXUIntVal(getDisplayText(),base);
+    val=(FXdouble)getDisplayText().toLong(base);
   return val;
   }
 
@@ -788,6 +786,7 @@ FXdouble Calculator::getDisplayValue() const {
 // Redisplay new value
 void Calculator::setDisplayValue(FXdouble val){
   FXint fp=fxieeedoubleclass(val);
+  FXString string;
   if(fp==-2 || fp==+2){
     setDisplayText("ERROR");
     if(beep) getApp()->beep();
@@ -802,10 +801,10 @@ void Calculator::setDisplayValue(FXdouble val){
     }
   else if(base==10){
     if(val==0.0) val=0.0;       // Don't ever print out -0 instead of 0
-    setDisplayText(FXStringVal(val,precision,exponent));
+    setDisplayText(string.fromDouble(val,precision,exponent));
     }
   else{
-    setDisplayText(FXStringVal((FXuint)floor(val),base));
+    setDisplayText(string.fromLong((FXlong)((0.0<=val)?val+0.5:val-0.5),base));
     }
   }
 
@@ -856,7 +855,7 @@ void Calculator::setBase(FXint b){
 
 
 // Set exponent mode
-void Calculator::setExponentMode(FXbool expmode){
+void Calculator::setExponentMode(FXuchar expmode){
   exponent=expmode;
   setDisplayValue(getnum());
   modifiers=0;
@@ -872,24 +871,24 @@ void Calculator::setPrecision(FXint prec){
 
 
 // Argument to sine, cosine, etc
-FXdouble Calculator::trigarg(FXdouble ang) const {
+FXdouble Calculator::trigarg(FXdouble a) const {
   switch(angles){
-    case ANG_DEG: return DEG2RAD(ang);
-    case ANG_GRA: return GRA2RAD(ang);
-    case ANG_RAD: return ang;
+    case ANG_DEG: return DEG2RAD(a);
+    case ANG_GRA: return GRA2RAD(a);
+    case ANG_RAD: return a;
     }
-  return ang;
+  return a;
   }
 
 
 // Result from arcsine, arccosine, etc
-FXdouble Calculator::trigres(FXdouble res) const {
+FXdouble Calculator::trigres(FXdouble r) const {
   switch(angles){
-    case ANG_DEG: return RAD2DEG(res);
-    case ANG_GRA: return RAD2GRA(res);
-    case ANG_RAD: return res;
+    case ANG_DEG: return RAD2DEG(r);
+    case ANG_GRA: return RAD2GRA(r);
+    case ANG_RAD: return r;
     }
-  return res;
+  return r;
   }
 
 
@@ -987,19 +986,19 @@ void Calculator::unary(FXuchar op){
   acc=0.0;
   switch(op){
     case UN_NOT:
-      acc=(FXdouble) (~((FXuint)floor(val)));
+      acc=(FXdouble) (~((FXlong)floor(val)));
       break;
     case UN_NEG:
       acc=-val;
       break;
     case UN_SHL:
-      acc=(FXdouble) (((FXuint)floor(val))<<1);
+      acc=(FXdouble) (((FXulong)floor(val))<<1);
       break;
     case UN_SHR:
-      acc=(FXdouble) (((FXuint)floor(val))>>1);
+      acc=(FXdouble) (((FXulong)floor(val))>>1);
       break;
     case UN_SAR:
-      acc=(FXdouble) ((((FXuint)floor(val))>>1) | (((FXuint)floor(val))&0x80000000));
+      acc=(FXdouble) (((FXlong)floor(val))>>1);
       break;
     case UN_RECIP:
       acc=1.0/val;
@@ -1084,13 +1083,13 @@ void Calculator::dyop(FXuchar op){
   acc=getnum();
   switch(op){
     case DY_OR:
-      acc=(FXdouble) (((FXuint)floor(acc)) | ((FXuint)floor(val)));
+      acc=(FXdouble) (((FXulong)floor(acc)) | ((FXulong)floor(val)));
       break;
     case DY_XOR:
-      acc=(FXdouble) (((FXuint)floor(acc)) ^ ((FXuint)floor(val)));
+      acc=(FXdouble) (((FXulong)floor(acc)) ^ ((FXulong)floor(val)));
       break;
     case DY_AND:
-      acc=(FXdouble) (((FXuint)floor(acc)) & ((FXuint)floor(val)));
+      acc=(FXdouble) (((FXulong)floor(acc)) & ((FXulong)floor(val)));
       break;
     case DY_SUB:
       acc=acc-val;
@@ -1251,12 +1250,11 @@ long Calculator::onUpdColor(FXObject* sender,FXSelector sel,void*){
 // Change font
 long Calculator::onCmdFont(FXObject*,FXSelector,void*){
   FXFontDialog fontdlg(this,"Change Display Font",DECOR_BORDER|DECOR_TITLE);
-  FXFontDesc fontdesc;
-  getDisplayFont()->getFontDesc(fontdesc);
-  fontdlg.setFontSelection(fontdesc);
+  FXFontDesc fontdesc=getDisplayFont()->getFontDesc();
+  fontdlg.setFontDesc(fontdesc);
   if(fontdlg.execute()){
     FXFont *oldfont=font;
-    fontdlg.getFontSelection(fontdesc);
+    fontdesc=fontdlg.getFontDesc();
     font=new FXFont(getApp(),fontdesc);
     font->create();
     setDisplayFont(font);
@@ -1268,18 +1266,18 @@ long Calculator::onCmdFont(FXObject*,FXSelector,void*){
 
 // Change exponential notation
 long Calculator::onCmdExponent(FXObject*,FXSelector sel,void* ptr){
-  if(FXSELID(sel)==ID_EXPONENT_ALWAYS && ptr) setExponentMode(TRUE);
-  else if(FXSELID(sel)==ID_EXPONENT_NEVER && ptr) setExponentMode(FALSE);
-  else setExponentMode(MAYBE);
+  if((FXSELID(sel)==ID_EXPONENT_ALWAYS) && ptr) setExponentMode(EXPONENT_ALWAYS);
+  else if((FXSELID(sel)==ID_EXPONENT_NEVER) && ptr) setExponentMode(EXPONENT_NEVER);
+  else setExponentMode(EXPONENT_IFNEEDED);
   return 1;
   }
 
 
 // Update exponential notation
 long Calculator::onUpdExponent(FXObject* sender,FXSelector sel,void*){
-  if(FXSELID(sel)==ID_EXPONENT_ALWAYS && exponent==TRUE)
+  if(FXSELID(sel)==ID_EXPONENT_ALWAYS && exponent==EXPONENT_ALWAYS)
     sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
-  else if(FXSELID(sel)==ID_EXPONENT_NEVER && exponent==FALSE)
+  else if(FXSELID(sel)==ID_EXPONENT_NEVER && exponent==EXPONENT_NEVER)
     sender->handle(this,FXSEL(SEL_COMMAND,ID_CHECK),NULL);
   else
     sender->handle(this,FXSEL(SEL_COMMAND,ID_UNCHECK),NULL);
@@ -1317,8 +1315,6 @@ long Calculator::onUpdBeep(FXObject* sender,FXSelector,void*){
   }
 
 
-
-
 // Popup help
 long Calculator::onCmdQuestion(FXObject*,FXSelector,void*){
   HelpWindow helpwindow(this,"Calculator Help");
@@ -1375,14 +1371,14 @@ long Calculator::onCmdDigit(FXObject*,FXSelector sel,void*){
     if(text[pos]=='-' || text[pos]=='+') pos++;     // Skip sign
     if(text[pos]=='0' || (text[pos] && text[pos+1] && text[pos+2])){
       while(text[pos+1]){ text[pos]=text[pos+1]; pos++; }
-      text[pos]=FXString::HEX[FXSELID(sel)-ID_0];
+      text[pos]=FXString::value2Digit[FXSELID(sel)-ID_0];
       }
     else{
-      text.append(FXString::HEX[FXSELID(sel)-ID_0]);
+      text.append(FXString::value2Digit[FXSELID(sel)-ID_0]);
       }
     }
   else if(digits<limit){
-    text+=FXString::HEX[FXSELID(sel)-ID_0];
+    text+=FXString::value2Digit[FXSELID(sel)-ID_0];
     digits++;
     }
   setDisplayText(text);
