@@ -3,23 +3,20 @@
 *                            B M P   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXBMPImage.h,v 1.19 2005/01/16 16:06:06 fox Exp $                        *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXBMPIMAGE_H
 #define FXBMPIMAGE_H
@@ -48,6 +45,7 @@ private:
   FXBMPImage &operator=(const FXBMPImage&);
 public:
   static const FXchar fileExt[];
+  static const FXchar mimeType[];
 public:
 
   /// Construct image from memory stream formatted in Microsoft BMP format
@@ -64,12 +62,14 @@ public:
   };
 
 
+#ifndef FXLOADBMP
+#define FXLOADBMP
+
 /**
-* Check if stream contains a bitmap, return TRUE if so.
+* Check if stream contains a bitmap, return true if so.
 */
 extern FXAPI FXbool fxcheckBMP(FXStream& store);
 
-
 /**
 * Load an BMP (Microsoft Bitmap) file from a stream.
 * Upon successful return, the pixel array and size are returned.
@@ -77,12 +77,25 @@ extern FXAPI FXbool fxcheckBMP(FXStream& store);
 */
 extern FXAPI FXbool fxloadBMP(FXStream& store,FXColor*& data,FXint& width,FXint& height);
 
-
 /**
 * Save an BMP (Microsoft Bitmap) file to a stream.
 */
 extern FXAPI FXbool fxsaveBMP(FXStream& store,const FXColor *data,FXint width,FXint height);
 
+/**
+* Load DIB (Device Independent Bitmap) file from stream.
+* Upon successful return, the pixel array and size are returned.
+* If an error occurred, the pixel array is set to NULL.
+*/
+extern FXAPI FXbool fxloadDIB(FXStream& store,FXColor*& data,FXint& width,FXint& height);
+
+/**
+* Save an DIB (Device Independent Bitmap) file to a stream.
+*/
+extern FXAPI FXbool fxsaveDIB(FXStream& store,const FXColor *data,FXint width,FXint height);
+
+#endif
+
 }
 
 #endif
