@@ -3,23 +3,20 @@
 *                             B i t m a p    O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXBitmap.h,v 1.37 2006/01/22 17:57:59 fox Exp $                          *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXBITMAP_H
 #define FXBITMAP_H
@@ -30,6 +27,7 @@
 
 namespace FX {
 
+
 // Image rendering hints
 enum {
   BITMAP_KEEP       = 0x00000001,       // Keep pixel data in client
@@ -91,6 +89,12 @@ public:
   /// To get to the option flags
   FXuint getOptions() const { return options; }
 
+  /// Set pixel data ownership flag
+  void setOwned(FXbool owned);
+
+  /// Get pixel data ownership flag
+  FXbool isOwned() const;
+
   /**
   * Populate the bitmap with new pixel data of the same size; it will assume
   * ownership of the pixel data if image BITMAP_OWNED option is passed.
@@ -179,7 +183,7 @@ public:
   * than the old one; blank areas are filled with color. There must be at
   * least one pixel of overlap between the old and the new bitmap.
   */
-  virtual void crop(FXint x,FXint y,FXint w,FXint h,FXbool color=0);
+  virtual void crop(FXint x,FXint y,FXint w,FXint h,FXbool color=false);
 
   /// Fill bitmap with uniform value
   virtual void fill(FXbool color);
@@ -191,10 +195,10 @@ public:
   virtual void load(FXStream& store);
 
   /// Save pixel data only
-  virtual bool savePixels(FXStream& store) const;
+  virtual FXbool savePixels(FXStream& store) const;
 
   /// Load pixel data only
-  virtual bool loadPixels(FXStream& store);
+  virtual FXbool loadPixels(FXStream& store);
 
   /// Cleanup
   virtual ~FXBitmap();
