@@ -3,23 +3,20 @@
 *                        C U R   C u r s o r    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2004 by Sander Jansen.   All Rights Reserved.              *
+* Copyright (C) 2001,2014 by Sander Jansen.   All Rights Reserved.              *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXCURCursor.h,v 1.13 2004/01/15 01:38:04 fox Exp $                       *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXCURCURSOR_H
 #define FXCURCURSOR_H
@@ -30,6 +27,7 @@
 
 namespace FX {
 
+
 /// CUR Cursor class
 class FXAPI FXCURCursor : public FXCursor {
   FXDECLARE(FXCURCursor)
@@ -39,6 +37,8 @@ private:
   FXCURCursor(const FXCURCursor&);
   FXCURCursor &operator=(const FXCURCursor&);
 public:
+  static const FXchar fileExt[];
+public:
 
   /**
   * Construct a cursor from memory stream in Microsoft CUR format.
@@ -60,6 +60,11 @@ public:
 #ifndef FXLOADICO
 #define FXLOADICO
 
+/**
+* Check if stream contains a ICO, return true if so.
+*/
+extern FXAPI FXbool fxcheckICO(FXStream& store);
+
 /**
 * Load an ICO (Microsoft icon format) file from a stream.
 * Upon successful return, the pixel array and size are returned.
@@ -67,7 +72,6 @@ public:
 */
 extern FXAPI FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
 
-
 /**
 * Save an ICO (Microsoft icon format) file to a stream.
 * If no hot-spot given, save as an ICO instead of a CUR resource.
