@@ -3,23 +3,20 @@
 *                    C h e c k   B u t t o n   W i d g e t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXCheckButton.h,v 1.26 2004/02/17 21:06:01 fox Exp $                     *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXCHECKBUTTON_H
 #define FXCHECKBUTTON_H
@@ -41,20 +38,26 @@ enum {
 
 
 /**
-* A check button is a tri-state button.  Normally, it is either
+* A Check Button is a tri-state button.  Normally, it is either
 * TRUE or FALSE, and toggles between TRUE or FALSE whenever it is pressed.
 * A third state MAYBE may be set to indicate that no selection has been made yet
 * by the user, or that the state is ambiguous.
-* When pressed, the check button sends a SEL_COMMAND to its target, and the
+* When pressed, the Check Button sends a SEL_COMMAND to its target, and the
 * message data represents the state of the check button.
+* The option CHECKBUTTON_AUTOGRAY (CHECKBUTTON_AUTOHIDE) causes the button to be
+* grayed out (hidden) if its handler does not respond to the SEL_UPDATE message.
+* With the CHECKBUTTON_PLUS option, the Check Button will draw a + or - sign instead
+* of a check.  You can use this to make collapsable panels, by hooking up a Check
+* Button to a layout manager via the ID_TOGGLE_SHOWN message.  This will give a
+* similar visual element as collapsing folders in a Tree List.
 */
 class FXAPI FXCheckButton : public FXLabel {
   FXDECLARE(FXCheckButton)
 protected:
   FXColor  checkColor;  // Color of check mark
   FXColor  boxColor;    // Color of check box
-  FXbool   check;       // Check state
-  FXbool   oldcheck;    // Old check state
+  FXuchar  check;       // Check state
+  FXuchar  oldcheck;    // Old check state
 protected:
   FXCheckButton();
 private:
@@ -95,10 +98,10 @@ public:
   virtual FXint getDefaultHeight();
 
   /// Set check button state (TRUE, FALSE or MAYBE)
-  void setCheck(FXbool state=TRUE);
+  void setCheck(FXuchar state=true,FXbool notify=false);
 
   /// Get check button state (TRUE, FALSE or MAYBE)
-  FXbool getCheck() const { return check; }
+  FXuchar getCheck() const { return check; }
 
   /// Change check button style
   void setCheckButtonStyle(FXuint style);
@@ -112,10 +115,10 @@ public:
   /// Set the box background color
   void setBoxColor(FXColor clr);
 
-  /// Get the box background color
+  /// Get the box check color
   FXColor getCheckColor() const { return checkColor; }
 
-  /// Set the box background color
+  /// Set the box check color
   void setCheckColor(FXColor clr);
 
   /// Save check button to a stream
