@@ -3,23 +3,20 @@
 *                          C o l o r   S e l e c t o r                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXColorSelector.h,v 1.24 2004/02/08 17:17:33 fox Exp $                   *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXCOLORSELECTOR_H
 #define FXCOLORSELECTOR_H
@@ -35,6 +32,8 @@ class FXTabBook;
 class FXColorBar;
 class FXColorWell;
 class FXColorWheel;
+class FXColorRing;
+class FXColorList;
 class FXList;
 class FXSlider;
 class FXTextField;
@@ -43,15 +42,24 @@ class FXIcon;
 class FXLabel;
 
 
+// Color panel tabs
+enum {
+  COLORTAB_COLOR_RING,
+  COLORTAB_RED_GREEN_BLUE,
+  COLORTAB_HUE_SATURATION_VALUE,
+  COLORTAB_CYAN_MAGENTA_YELLOW,
+  COLORTAB_COLOR_LIST
+  };
+
+
 /// Color selection widget
 class FXAPI FXColorSelector : public FXPacker {
   FXDECLARE(FXColorSelector)
 protected:
   FXTabBook    *panels;               // Color panes
   FXColorWell  *well;                 // Main well
-  FXList       *list;                 // List of color names
-  FXColorBar   *bar;                  // Color bar
-  FXColorWheel *wheel;                // Color wheel
+  FXColorList  *list;                 // List of color names
+  FXColorRing  *wheel;                // Color ring
   FXSlider     *rgbaslider[4];        // RGBA sliders
   FXTextField  *rgbatext[4];          // RGBA text fields
   FXSlider     *hsvaslider[4];        // HSVA sliders
@@ -69,8 +77,6 @@ protected:
   FXButton     *cancel;               // Cancel button
   FXfloat       rgba[4];              // Accurate RGBA color
   FXfloat       hsva[4];              // Accurate HSVA color
-protected:
-  static const FXchar* wellname[24];  // Well names
 protected:
   FXColorSelector(){}
   void updateWell();
@@ -78,8 +84,6 @@ private:
   FXColorSelector(const FXColorSelector&);
   FXColorSelector &operator=(const FXColorSelector&);
 public:
-  long onCmdColor(FXObject*,FXSelector,void*);
-  long onChgColor(FXObject*,FXSelector,void*);
   long onCmdWell(FXObject*,FXSelector,void*);
   long onChgWell(FXObject*,FXSelector,void*);
   long onCmdRGBSlider(FXObject*,FXSelector,void*);
@@ -96,9 +100,7 @@ public:
   long onUpdCMYText(FXObject*,FXSelector,void*);
   long onCmdList(FXObject*,FXSelector,void*);
   long onCmdCustomWell(FXObject*,FXSelector,void*);
-  long onChgCustomWell(FXObject*,FXSelector,void*);
   long onCmdSetValue(FXObject*,FXSelector,void*);
-  long onCmdActivePane(FXObject*,FXSelector,void*);
   long onCmdAlphaSlider(FXObject*,FXSelector,void*);
   long onUpdAlphaSlider(FXObject*,FXSelector,void*);
   long onCmdAlphaText(FXObject*,FXSelector,void*);
@@ -106,9 +108,9 @@ public:
   long onUpdAlphaLabel(FXObject*,FXSelector,void*);
   long onCmdWheel(FXObject*,FXSelector,void*);
   long onUpdWheel(FXObject*,FXSelector,void*);
-  long onCmdBar(FXObject*,FXSelector,void*);
-  long onUpdBar(FXObject*,FXSelector,void*);
   long onCmdColorPick(FXObject*,FXSelector,void*);
+  long onCmdSetIntValue(FXObject*,FXSelector,void*);
+  long onCmdGetIntValue(FXObject*,FXSelector,void*);
 public:
   enum {
     ID_CUSTOM_FIRST=FXPacker::ID_LAST,
@@ -132,11 +134,8 @@ public:
     ID_CMY_MAGENTA_TEXT,
     ID_CMY_YELLOW_TEXT,
     ID_DIAL_WHEEL,
-    ID_COLOR_BAR,
     ID_COLOR_LIST,
     ID_WELL_CHANGED,
-    ID_COLOR,
-    ID_ACTIVEPANE,
     ID_ALPHA_SLIDER,
     ID_ALPHA_TEXT,
     ID_ALPHA_LABEL,
@@ -148,9 +147,6 @@ public:
   /// Construct a new ColorSelector
   FXColorSelector(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
-  /// Create the ColorSelector
-  virtual void create();
-
   /// Return a pointer to the "Accept" button
   FXButton *acceptButton() const { return accept; }
 
@@ -158,17 +154,29 @@ public:
   FXButton *cancelButton() const { return cancel; }
 
   /// Set the selected color
-  void setRGBA(FXColor clr);
+  void setRGBA(FXColor color,FXbool notify=false);
 
   /// Get the selected color
   FXColor getRGBA() const;
 
-  /// Return true if only opaque colors allowed
-  FXbool isOpaqueOnly() const;
+  /// Change active panel
+  void setActivePanel(FXint pnl=COLORTAB_COLOR_RING);
+
+  /// Return active panel
+  FXint getActivePanel() const;
+
+  /// Change well color
+  void setWellColor(FXint w,FXColor clr);
+
+  /// Return well color
+  FXColor getWellColor(FXint w) const;
 
   /// Change opaque only mode
   void setOpaqueOnly(FXbool opaque);
 
+  /// Return true if only opaque colors allowed
+  FXbool isOpaqueOnly() const;
+
   /// Save to a stream
   virtual void save(FXStream& store) const;
 
