@@ -3,29 +3,28 @@
 *               D e v i c e   C o n t e x t   B a s e   C l a s s               *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXDC.h,v 1.33 2005/01/16 16:06:06 fox Exp $                              *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXDC_H
 #define FXDC_H
 
+
 namespace FX {
 
+
 /// Drawing (BITBLT) functions
 enum FXFunction {
   BLT_CLR,                        /// D := 0
@@ -152,6 +151,7 @@ class FXRegion;
 * application regardless of the actual device surface being utilized.
 */
 class FXAPI FXDC {
+  friend class FXFont;
 private:
   FXApp           *app;         // Application
 protected:
@@ -256,6 +256,12 @@ public:
   virtual void fillConcavePolygonRel(const FXPoint* points,FXuint npoints);
   virtual void fillComplexPolygonRel(const FXPoint* points,FXuint npoints);
 
+  /// Fill vertical gradient rectangle
+  virtual void fillVerticalGradient(FXint x,FXint y,FXint w,FXint h,FXColor top,FXColor bottom);
+
+  /// Fill horizontal gradient rectangle
+  virtual void fillHorizontalGradient(FXint x,FXint y,FXint w,FXint h,FXColor left,FXColor right);
+
   /// Draw hashed box
   virtual void drawHashBox(FXint x,FXint y,FXint w,FXint h,FXint b=1);
 
@@ -265,6 +271,9 @@ public:
   /// Draw area from source
   virtual void drawArea(const FXDrawable* source,FXint sx,FXint sy,FXint sw,FXint sh,FXint dx,FXint dy);
 
+  /// Draw area stretched area from source
+  virtual void drawArea(const FXDrawable* source,FXint sx,FXint sy,FXint sw,FXint sh,FXint dx,FXint dy,FXint dw,FXint dh);
+
   /// Draw image
   virtual void drawImage(const FXImage* image,FXint dx,FXint dy);
 
@@ -277,7 +286,11 @@ public:
   virtual void drawIconSunken(const FXIcon* icon,FXint dx,FXint dy);
 
   /// Draw string with base line starting at x, y
+  virtual void drawText(FXint x,FXint y,const FXString& string);
   virtual void drawText(FXint x,FXint y,const FXchar* string,FXuint length);
+
+  /// Draw text starting at x, y over filled background
+  virtual void drawImageText(FXint x,FXint y,const FXString& string);
   virtual void drawImageText(FXint x,FXint y,const FXchar* string,FXuint length);
 
   /// Set foreground drawing color
