@@ -3,23 +3,20 @@
 *                     D i r e c t o r y   L i s t   W i d g e t                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXDirList.h,v 1.59 2004/02/08 17:17:33 fox Exp $                         *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXDIRLIST_H
 #define FXDIRLIST_H
@@ -31,10 +28,9 @@
 namespace FX {
 
 
+class FXDirList;
+class FXFileAssociations;
 struct FXFileAssoc;
-class  FXFileDict;
-class  FXIcon;
-class  FXDirList;
 
 
 /// Directory List options
@@ -50,88 +46,108 @@ class FXAPI FXDirItem : public FXTreeItem {
   FXDECLARE(FXDirItem)
   friend class FXDirList;
 protected:
-  FXFileAssoc  *assoc;                // File association
-  FXDirItem    *link;                 // Link to next item
-  FXDirItem    *list;                 // List of child items
-  unsigned long size;                 // File size (if a file)
-  FXTime        date;                 // Time of item
+  FXFileAssoc *assoc;           // File association
+  FXDirItem   *link;            // Link to next item
+  FXDirItem   *list;            // List of child items
+  FXlong       size;            // File size (if a file)
+  FXTime       date;            // Time of item
+  FXuint       mode;            // Mode flags
+private:
+  FXDirItem(const FXDirItem&);
+  FXDirItem& operator=(const FXDirItem&);
 protected:
-  FXDirItem():assoc(NULL),link(NULL),list(NULL),size(0),date(0){}
-protected:
-  enum {
-    FOLDER      = 512,                // Directory item
-    EXECUTABLE  = 1024,               // Executable item
-    SYMLINK     = 2048,               // Symbolic linked item
-    CHARDEV     = 4096,               // Character special item
-    BLOCKDEV    = 8192,               // Block special item
-    FIFO        = 16384,              // FIFO item
-    SOCK        = 32768               // Socket item
-    };
+  FXDirItem():assoc(NULL),link(NULL),list(NULL),size(0L),date(0),mode(0){}
 public:
 
   /// Constructor
-  FXDirItem(const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL):FXTreeItem(text,oi,ci,ptr),assoc(NULL),link(NULL),list(NULL),size(0),date(0){state=HASITEMS;}
+  FXDirItem(const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL):FXTreeItem(text,oi,ci,ptr),assoc(NULL),link(NULL),list(NULL),size(0),date(0),mode(0){}
 
   /// Return true if this is a file item
-  FXbool isFile() const { return (state&(FOLDER|BLOCKDEV|CHARDEV|FIFO|SOCK))==0; }
+  FXbool isFile() const { return (mode&(FXIO::File))!=0; }
 
   /// Return true if this is a directory item
-  FXbool isDirectory() const { return (state&FOLDER)!=0; }
+  FXbool isDirectory() const { return (mode&FXIO::Directory)!=0; }
 
   /// Return true if this is an executable item
-  FXbool isExecutable() const { return (state&EXECUTABLE)!=0; }
+  FXbool isExecutable() const { return (mode&FXIO::File)!=0 && (mode&FXIO::AllExec)!=0; }
 
   /// Return true if this is a symbolic link item
-  FXbool isSymlink() const { return (state&SYMLINK)!=0; }
+  FXbool isSymlink() const { return (mode&FXIO::SymLink)!=0; }
 
   /// Return true if this is a character device item
-  FXbool isChardev() const { return (state&CHARDEV)!=0; }
+  FXbool isChardev() const { return (mode&FXIO::Character)!=0; }
 
   /// Return true if this is a block device item
-  FXbool isBlockdev() const { return (state&BLOCKDEV)!=0; }
+  FXbool isBlockdev() const { return (mode&FXIO::Block)!=0; }
 
   /// Return true if this is an FIFO item
-  FXbool isFifo() const { return (state&FIFO)!=0; }
+  FXbool isFifo() const { return (mode&FXIO::Fifo)!=0; }
 
   /// Return true if this is a socket
-  FXbool isSocket() const { return (state&SOCK)!=0; }
+  FXbool isSocket() const { return (mode&FXIO::Socket)!=0; }
+
+  /// Set the file-association object for this item
+  void setAssoc(FXFileAssoc* a){ assoc=a; }
 
   /// Return the file-association object for this item
   FXFileAssoc* getAssoc() const { return assoc; }
 
-  /// Return the file size for this item
-  unsigned long getSize() const { return size; }
+  /// Set the file size for this item
+  void setSize(FXlong s){ size=s; }
 
-  /// Return the date for this item
+  /// Return the file size for this item
+  FXlong getSize() const { return size; }
+
+  /// Set the date for this item, in nanoseconds
+  void setDate(FXTime d){ date=d; }
+
+  /// Return the date for this item, in nanoseconds
   FXTime getDate() const { return date; }
+
+  /// Set file mode bits
+  void setMode(FXuint m){ mode=m; }
+
+  /// Return file mode flags
+  FXuint getMode() const { return mode; }
   };
 
 
-/// Directory tree List
+/**
+* A Directory List widget provides a tree-structured view of the file system.
+* It automatically updates itself periodically by re-scanning the file system
+* for any changes.  As it scans the displayed directories and files, it automatically
+* determines the icons to be displayed by consulting the file-associations registry
+* settings.  A number of messages can be sent to the Directory List to control the
+* filter pattern, sorting order, case sensitivity, and hidden file display mode.
+* The Directory list widget supports drags and drops of files.
+*/
 class FXAPI FXDirList : public FXTreeList {
   FXDECLARE(FXDirList)
 protected:
-  FXFileDict   *associations;         // Association table
-  FXDirItem    *list;                 // Root item list
-  FXString      dropdirectory;        // Drop directory
-  FXDragAction  dropaction;           // Drop action
-  FXString      dragfiles;            // Dragged files
-  FXString      pattern;              // Pattern of file names
-  FXuint        matchmode;            // File wildcard match mode
-  FXuint        counter;              // Refresh counter
-  FXIcon       *open_folder;          // Open folder icon
-  FXIcon       *closed_folder;        // Closed folder icon
-  FXIcon       *mini_doc;             // Document icon
-  FXIcon       *mini_app;             // Application icon
-  FXIcon       *cdromicon;
-  FXIcon       *harddiskicon;
-  FXIcon       *networkicon;
-  FXIcon       *floppyicon;
-  FXIcon       *zipdiskicon;
+  FXFileAssociations *associations;     // Association table
+  FXDirItem          *list;             // Root item list
+  FXIcon             *opendiricon;      // Open folder icon
+  FXIcon             *closeddiricon;    // Closed folder icon
+  FXIcon             *documenticon;     // Document icon
+  FXIcon             *applicationicon;  // Application icon
+  FXIcon             *cdromicon;        // CDROM icon
+  FXIcon             *harddiskicon;     // Hard drive icon
+  FXIcon             *networkicon;      // Network icon
+  FXIcon             *floppyicon;       // Floppy icon
+  FXIcon             *zipdiskicon;      // Zip disk icon
+  FXString            pattern;          // Pattern of file names
+  FXString            dropdirectory;    // Drop directory
+  FXString            dragfiles;        // Dragged file names
+  FXString            dropfiles;        // Dropped file names
+  FXDragAction        dropaction;       // Drop action
+  FXuint              matchmode;        // File wildcard match mode
+  FXuint              counter;          // Refresh counter
+  FXbool              draggable;        // Dragable files
 protected:
   FXDirList();
   void listRootItems();
   void listChildItems(FXDirItem *par);
+  FXString getSelectedFiles() const;
   virtual FXTreeItem* createItem(const FXString& text,FXIcon* oi,FXIcon* ci,void* ptr);
 private:
   FXDirList(const FXDirList&);
@@ -168,6 +184,12 @@ public:
   long onCmdSortCase(FXObject*,FXSelector,void*);
   long onUpdSortCase(FXObject*,FXSelector,void*);
   long onCmdRefresh(FXObject*,FXSelector,void*);
+  long onUpdHaveSel(FXObject*,FXSelector,void*);
+  long onCmdDeleteSel(FXObject*,FXSelector,void*);
+  long onCmdDropAsk(FXObject*,FXSelector,void*);
+  long onCmdDropCopy(FXObject*,FXSelector,void*);
+  long onCmdDropMove(FXObject*,FXSelector,void*);
+  long onCmdDropLink(FXObject*,FXSelector,void*);
 public:
   static FXint ascending(const FXTreeItem* a,const FXTreeItem* b);
   static FXint descending(const FXTreeItem* a,const FXTreeItem* b);
@@ -176,6 +198,10 @@ public:
 public:
   enum {
     ID_REFRESHTIMER=FXTreeList::ID_LAST,
+    ID_DROPASK,
+    ID_DROPCOPY,
+    ID_DROPMOVE,
+    ID_DROPLINK,
     ID_SHOW_FILES,
     ID_HIDE_FILES,
     ID_TOGGLE_FILES,
@@ -186,6 +212,7 @@ public:
     ID_SORT_REVERSE,
     ID_SORT_CASE,
     ID_REFRESH,
+    ID_DELETE_SEL,
     ID_LAST
     };
 public:
@@ -202,71 +229,92 @@ public:
   /// Destroy server-side resources
   virtual void destroy();
 
-  /// Scan the directories and update the items if needed, or if force is TRUE
-  void scan(FXbool force=TRUE);
+  /// Scan the directories and update the items if needed, or if force is true
+  void scan(FXbool force=true);
 
-  /// Return TRUE if item is a directory
-  FXbool isItemDirectory(const FXTreeItem* item) const;
-
-  /// Return TRUE if item is a file
-  FXbool isItemFile(const FXTreeItem* item) const;
-
-  /// Return TRUE if item is executable
-  FXbool isItemExecutable(const FXTreeItem* item) const;
-
-  /// Collapse tree
-  virtual FXbool collapseTree(FXTreeItem* tree,FXbool notify=FALSE);
-
-  /// Expand tree
-  virtual FXbool expandTree(FXTreeItem* tree,FXbool notify=FALSE);
-
-  /// Set current file
-  void setCurrentFile(const FXString& file,FXbool notify=FALSE);
+  /// Set current file; return true if success
+  FXbool setCurrentFile(const FXString& file,FXbool notify=false);
 
   /// Return current file
   FXString getCurrentFile() const;
 
-  /// Set current directory
-  void setDirectory(const FXString& path,FXbool notify=FALSE);
+  /// Set current directory; return true if success
+  FXbool setDirectory(const FXString& path,FXbool notify=false);
 
   /// Return current directory
   FXString getDirectory() const;
 
-  /// Return absolute pathname of item
-  FXString getItemPathname(const FXTreeItem* item) const;
-
-  /// Return the item from the absolute pathname
-  FXTreeItem* getPathnameItem(const FXString& path);
-
   /// Change wildcard matching pattern
   void setPattern(const FXString& ptrn);
 
   /// Return wildcard pattern
   FXString getPattern() const { return pattern; }
 
+  /// Return absolute pathname of item
+  FXString getItemPathname(const FXTreeItem* item) const;
+
+  /// Return the (closest) item from the absolute pathname
+  FXTreeItem* getPathnameItem(const FXString& path);
+
+  /// Return true if item is a file
+  FXbool isItemFile(const FXTreeItem* item) const;
+
+  /// Return true if item is a directory
+  FXbool isItemDirectory(const FXTreeItem* item) const;
+
+  /// Return true if item is executable
+  FXbool isItemExecutable(const FXTreeItem* item) const;
+
+  /// Return true if this is a symbolic link item
+  FXbool isItemSymlink(const FXTreeItem* item) const;
+
+  /// Return file association of item
+  FXFileAssoc* getItemAssoc(const FXTreeItem* item) const;
+
+  /// Return the file size for this item
+  FXlong getItemSize(const FXTreeItem* item) const;
+
+  /// Return the date for this item, in nanoseconds
+  FXTime getItemDate(const FXTreeItem* item) const;
+
+  /// Return the mode bits for this item
+  FXuint getItemMode(const FXTreeItem* item) const;
+
+  /// Collapse tree
+  virtual FXbool collapseTree(FXTreeItem* tree,FXbool notify=false);
+
+  /// Expand tree
+  virtual FXbool expandTree(FXTreeItem* tree,FXbool notify=false);
+
+  /// Change wildcard matching mode (see FXPath)
+  void setMatchMode(FXuint mode);
+
   /// Return wildcard matching mode
   FXuint getMatchMode() const { return matchmode; }
 
-  /// Change wildcard matching mode
-  void setMatchMode(FXuint mode);
+  /// Show or hide normal files
+  void showFiles(FXbool flag);
 
-  /// Return TRUE if showing files as well as directories
+  /// Return true if showing files as well as directories
   FXbool showFiles() const;
 
-  /// Show or hide normal files
-  void showFiles(FXbool showing);
+  /// Show or hide hidden files and directories
+  void showHiddenFiles(FXbool flag);
 
-  /// Return TRUE if showing hidden files and directories
+  /// Return true if showing hidden files and directories
   FXbool showHiddenFiles() const;
 
-  /// Show or hide hidden files and directories
-  void showHiddenFiles(FXbool showing);
-
-  /// Change file associations
-  void setAssociations(FXFileDict* assoc);
+  /// Change file associations; delete the old one unless it was shared
+  void setAssociations(FXFileAssociations* assoc,FXbool owned=false);
 
   /// Return file associations
-  FXFileDict* getAssociations() const { return associations; }
+  FXFileAssociations* getAssociations() const { return associations; }
+
+  /// Set draggable files
+  void setDraggableFiles(FXbool flag);
+
+  /// Are files draggable
+  FXbool getDraggableFiles() const { return draggable; }
 
   /// Save to stream
   virtual void save(FXStream& store) const;
