@@ -3,23 +3,20 @@
 *                        D o c k B a r   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXDockBar.h,v 1.17.2.1 2005/02/10 15:41:36 fox Exp $                         *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXDOCKBAR_H
 #define FXDOCKBAR_H
@@ -30,13 +27,17 @@
 
 namespace FX {
 
+
 class FXDockSite;
 
 
 /**
 * A dock bar widget can be docked inside a dock site widget, or floated
 * around freely.  Users can move, undock, and dock the dock bar widget
-* by means of a handle such as a tool bar grip.
+* by means of a handle such as a tool bar grip.  When docking, the dock
+* bar sends a SEL_DOCKED message to its target; when undocking, it sends
+* a SEL_FLOATED message.  In either case the dock site involved is passed
+* in the void* pointer argument of the message.
 */
 class FXAPI FXDockBar : public FXPacker {
   FXDECLARE(FXDockBar)
@@ -46,13 +47,34 @@ protected:
   FXint        gripx;           // Grip offset x
   FXint        gripy;           // Grip offset y
   FXuchar      allowed;         // Where we're allowed to dock
+//  FXuchar      mode;            // Dragging mode
+//protected:
+//  static const FXDefaultCursor cursorType[16];
 protected:
   FXDockBar();
-  FXbool insideDock(FXDockSite* docksite,FXint barx,FXint bary);
+  FXbool isAllowable(FXuint hints) const;
+//  FXuchar where(FXint x,FXint y) const;
+protected:
+  enum {
+    DRAG_NONE        = 0,
+    DRAG_TOP         = 1,
+    DRAG_BOTTOM      = 2,
+    DRAG_LEFT        = 4,
+    DRAG_RIGHT       = 8,
+    DRAG_TOPLEFT     = (DRAG_TOP|DRAG_LEFT),
+    DRAG_TOPRIGHT    = (DRAG_TOP|DRAG_RIGHT),
+    DRAG_BOTTOMLEFT  = (DRAG_BOTTOM|DRAG_LEFT),
+    DRAG_BOTTOMRIGHT = (DRAG_BOTTOM|DRAG_RIGHT)
+    };
 private:
   FXDockBar(const FXDockBar&);
   FXDockBar &operator=(const FXDockBar&);
 public:
+//  long onEnter(FXObject*,FXSelector,void*);
+//  long onLeave(FXObject*,FXSelector,void*);
+//  long onMotion(FXObject*,FXSelector,void*);
+//  long onLeftBtnPress(FXObject*,FXSelector,void*);
+//  long onLeftBtnRelease(FXObject*,FXSelector,void*);
   long onCmdUndock(FXObject*,FXSelector,void*);
   long onUpdUndock(FXObject*,FXSelector,void*);
   long onCmdDockTop(FXObject*,FXSelector,void*);
@@ -114,6 +136,11 @@ public:
   /// Return true if docked
   FXbool isDocked() const;
 
+  /**
+  * Check if the dock bar would dock or undock if at locaton barx, bary.
+  */
+  FXbool insideDock(FXDockSite* docksite,FXint barx,FXint bary);
+
   /**
   * Set parent when docked.
   * If it was docked, reparent under the new docking window.
@@ -143,26 +170,26 @@ public:
   * However, if after is -1, it will be docked as the innermost bar just before
   * the work-area, while if after is 0, if will be docked as the outermost bar.
   */
-  virtual void dock(FXDockSite* docksite,FXWindow* before=NULL);
+  virtual void dock(FXDockSite* docksite,FXWindow* other=NULL,FXbool notify=false);
 
   /**
   * Dock the bar against the given side, near the given position relative
   * to the toolbar dock's origin.
   */
-  virtual void dock(FXDockSite* docksite,FXint localx,FXint localy);
+  virtual void dock(FXDockSite* docksite,FXint localx,FXint localy,FXbool notify);
 
   /**
   * Undock or float the bar.
   * The initial position of the wet dock is a few pixels
   * below and to the right of the original docked position.
   */
-  virtual void undock(FXint rootx,FXint rooty);
+  virtual void undock(FXint rootx,FXint rooty,FXbool notify=false);
 
   /**
-  * Change set of sides where docking is allowed.
-  * The default is to allow docking on all sides.
+  * Change set of sides (a combination of ALLOW_TOP, ALLOW_LEFT, etc.),
+  * where docking is allowed. The default is to allow docking on all sides.
   */
-  void allowedSides(FXuchar allow=ALLOW_EVERYWHERE){ allowed=allow; }
+  void allowedSides(FXuchar allow){ allowed=allow; }
 
   /**
   * Return set of sides where docking is allowed
