@@ -3,23 +3,20 @@
 *                   F i l e   S e l e c t i o n   D i a l o g                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXFileDialog.h,v 1.26 2004/02/20 21:16:57 fox Exp $                      *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXFILEDIALOG_H
 #define FXFILEDIALOG_H
@@ -32,6 +29,8 @@ namespace FX {
 
 
 class FXFileSelector;
+class FXIconSource;
+class FXFileAssociations;
 
 
 /// File selection dialog
@@ -39,8 +38,11 @@ class FXAPI FXFileDialog : public FXDialogBox {
   FXDECLARE(FXFileDialog)
 protected:
   FXFileSelector *filebox;
+protected:
+  static const FXchar sectionName[];
 protected:
   FXFileDialog(){}
+  void initdialog();
 private:
   FXFileDialog(const FXFileDialog&);
   FXFileDialog &operator=(const FXFileDialog&);
@@ -52,6 +54,9 @@ public:
   /// Construct free-floating file dialog box
   FXFileDialog(FXApp* a,const FXString& name,FXuint opts=0,FXint x=0,FXint y=0,FXint w=500,FXint h=300);
 
+  /// Hide this window
+  virtual void hide();
+
   /// Change file name
   void setFilename(const FXString& path);
 
@@ -88,18 +93,27 @@ public:
 
   /**
   * After setting the list of patterns, this call will
-  * initially select pattern n as the active one.
+  * initially select pattern patno as the active one.
   */
-  void setCurrentPattern(FXint n);
+  void setCurrentPattern(FXint patno);
 
   /// Return current pattern number
   FXint getCurrentPattern() const;
 
+  /// Change pattern text for pattern number
+  void setPatternText(FXint patno,const FXString& text);
+
   /// Get pattern text for given pattern number
   FXString getPatternText(FXint patno) const;
 
-  /// Change pattern text for pattern number
-  void setPatternText(FXint patno,const FXString& text);
+  /// Return number of patterns
+  FXint getNumPatterns() const;
+
+  /// Allow pattern entry
+  void allowPatternEntry(FXbool flag);
+
+  /// Return true if pattern entry is allowed
+  FXbool allowPatternEntry() const;
 
   /// Change directory
   void setDirectory(const FXString& path);
@@ -113,35 +127,83 @@ public:
   /// Return the inter-item spacing (in pixels)
   FXint getItemSpace() const;
 
+  /// Change file selection mode; the default is SELECTFILE_ANY
+  void setSelectMode(FXuint mode);
+
+  /// Return file selection mode
+  FXuint getSelectMode() const;
+
+  /// Change wildcard matching mode (see FXPath)
+  void setMatchMode(FXuint mode);
+
+  /// Return wildcard matching mode
+  FXuint getMatchMode() const;
+
+  /// Return true if showing hidden files
+  FXbool showHiddenFiles() const;
+
+  /// Show or hide hidden files
+  void showHiddenFiles(FXbool flag);
+
+  /// Return true if image preview on
+  FXbool showImages() const;
+
+  /// Show or hide preview images
+  void showImages(FXbool flag);
+
+  /// Return images preview size
+  FXint getImageSize() const;
+
+  /// Change images preview size
+  void setImageSize(FXint size);
+
+  /// Show readonly button
+  void showReadOnly(FXbool flag);
+
+  /// Return true if readonly is shown
+  FXbool shownReadOnly() const;
+
+  /// Set initial state of readonly button
+  void setReadOnly(FXbool flag);
+
+  /// Get readonly state
+  FXbool getReadOnly() const;
+
   /// Change File List style
   void setFileBoxStyle(FXuint style);
 
   /// Return File List style
   FXuint getFileBoxStyle() const;
 
-  /// Change file selection mode
-  void setSelectMode(FXuint mode);
+  /// Allow or disallow navigation
+  void allowNavigation(FXbool flag);
 
-  /// Return file selection mode
-  FXuint getSelectMode() const;
+  /// Is navigation allowed?
+  FXbool allowNavigation() const;
 
-  /// Change wildcard matching mode
-  void setMatchMode(FXuint mode);
+  /// Set draggable files
+  void setDraggableFiles(FXbool flag);
 
-  /// Return wildcard matching mode
-  FXuint getMatchMode() const;
+  /// Are files draggable?
+  FXbool getDraggableFiles() const;
 
-  /// Show readonly button
-  void showReadOnly(FXbool show);
+  /// Set file time format
+  void setTimeFormat(const FXString& fmt);
 
-  /// Return TRUE if readonly is shown
-  FXbool shownReadOnly() const;
+  /// Return file time format
+  FXString getTimeFormat() const;
 
-  /// Set initial state of readonly button
-  void setReadOnly(FXbool state);
+  /// Change file associations; delete old ones if owned
+  void setAssociations(FXFileAssociations* assoc,FXbool owned=false);
 
-  /// Get readonly state
-  FXbool getReadOnly() const;
+  /// Return file associations
+  FXFileAssociations* getAssociations() const;
+
+  /// Change icon loader
+  void setIconSource(FXIconSource* src);
+
+  /// Return icon loader
+  FXIconSource* getIconSource() const;
 
   /// Open existing filename
   static FXString getOpenFilename(FXWindow* owner,const FXString& caption,const FXString& path,const FXString& patterns="*",FXint initial=0);
