@@ -3,23 +3,20 @@
 *                        F o n t   S e l e c t i o n   B o x                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1999,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1999,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXFontSelector.h,v 1.18 2006/01/22 17:58:02 fox Exp $                    *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXFONTSELECTOR_H
 #define FXFONTSELECTOR_H
@@ -118,11 +115,17 @@ public:
   /// Return a pointer to the "Cancel" button
   FXButton *cancelButton() const { return cancel; }
 
+  /// Set font selection as a string
+  void setFont(const FXString& string);
+
+  /// Get font selection as a string
+  FXString getFont() const;
+
   /// Set font selection
-  void setFontSelection(const FXFontDesc& fontdesc);
+  void setFontDesc(const FXFontDesc& fontdesc);
 
   /// Get font selection
-  void getFontSelection(FXFontDesc& fontdesc) const;
+  const FXFontDesc& getFontDesc() const;
 
   /// Save to a stream
   virtual void save(FXStream& store) const;
