@@ -3,23 +3,20 @@
 *                        G I F   C u r so r   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by Daniel Gehriger.   All Rights Reserved.            *
+* Copyright (C) 2000,2014 by Daniel Gehriger.   All Rights Reserved.            *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXGIFCursor.h,v 1.20 2005/01/16 16:06:06 fox Exp $                       *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXGIFCURSOR_H
 #define FXGIFCURSOR_H
@@ -66,23 +63,25 @@ public:
 #define FXLOADGIF
 
 /**
-* Check if stream contains a GIF, return TRUE if so.
+* Check if stream contains a GIF, return true if so.
 */
 extern FXAPI FXbool fxcheckGIF(FXStream& store);
 
 
 /**
-* Load an GIF (Graphics Interchange Format) file from a stream.
-* Upon successful return, the pixel array and size are returned.
-* If an error occurred, the pixel array is set to NULL.
+* Load an GIF (Graphics Interchange Format) file from a stream; if the flag
+* flag is true, the background color is considered transparent.  Upon successful return,
+* the pixel array and size are returned.  If an error occurred, the pixel array is set to NULL.
 */
-extern FXAPI FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height);
+extern FXAPI FXbool fxloadGIF(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXbool flag=true);
 
 
 /**
-* Save an GIF (Graphics Interchange Format) file to a stream.
+* Save an GIF (Graphics Interchange Format) file to a stream.  If flag
+* is true, the faster Floyd-Steinberg dither method instead of the slower Wu
+* quantization algorithm.
 */
-extern FXAPI FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool fast=TRUE);
+extern FXAPI FXbool fxsaveGIF(FXStream& store,const FXColor *data,FXint width,FXint height,FXbool flag=true);
 
 #endif
 
