@@ -3,23 +3,20 @@
 *                           O p e n G L   O b j e c t                           *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXGLObject.h,v 1.28 2006/01/22 17:58:03 fox Exp $                        *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXGLOBJECT_H
 #define FXGLOBJECT_H
@@ -35,8 +32,6 @@ class FXGLViewer;
 class FXGLObject;
 
 
-// List of objects
-typedef FXObjectListOf<FXGLObject> FXGLObjectList;
 
 /// Basic OpenGL object
 class FXAPI FXGLObject : public FXObject {
@@ -82,13 +77,8 @@ public:
   };
 
 
-// Suppress warning about FXGLGroup::list not being exported
-#ifdef _MSC_VER
-#if _MSC_VER >= 1200
-#pragma warning( push )
-#endif
-#pragma warning( disable : 4251 )
-#endif
+/// List of GL objects
+typedef FXObjectListOf<FXGLObject> FXGLObjectList;
 
 
 /// Group object
@@ -122,7 +112,7 @@ public:
   /// Identify object by means of path
   virtual FXGLObject* identify(FXuint* path);
 
-  /// Return TRUE if group can be dragged
+  /// Return true if group can be dragged
   virtual FXbool canDrag() const;
 
   /// Drag group object
@@ -137,12 +127,21 @@ public:
   /// Insert child object at given position
   void insert(FXint pos,FXGLObject* obj){ list.insert(pos,obj); }
 
+  /// Insert list of child objects at given position
+  void insert(FXint pos,const FXGLObjectList& objs){ list.insert(pos,objs); }
+
   /// Prepend child object
   void prepend(FXGLObject* obj){ list.prepend(obj); }
 
+  /// Prepend list of child objects at given position
+  void prepend(const FXGLObjectList& objs){ list.prepend(objs); }
+
   /// Append child object
   void append(FXGLObject* obj){ list.append(obj); }
 
+  /// Append list of child objects at given position
+  void append(const FXGLObjectList& objs){ list.append(objs); }
+
   /// Replace child object
   void replace(FXint pos,FXGLObject* obj){ list.replace(pos,obj); }
 
@@ -164,14 +163,6 @@ public:
   };
 
 
-// Restore previous warning levels
-#ifdef _MSC_VER
-#if _MSC_VER >= 1200
-#pragma warning( pop )
-#endif
-#endif
-
-
 /// OpenGL Point Object
 class FXAPI FXGLPoint : public FXGLObject {
   FXDECLARE(FXGLPoint)
