@@ -3,23 +3,20 @@
 *                          H e a d e r   W i d g e t                            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXHeader.h,v 1.70 2006/01/22 17:58:04 fox Exp $                          *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXHEADER_H
 #define FXHEADER_H
@@ -52,38 +49,40 @@ class FXAPI FXHeaderItem : public FXObject {
   friend class FXHeader;
 protected:
   FXString  label;      // Text of item
+  FXString  tip;        // Tooltip of item
   FXIcon   *icon;       // Icon of item
-  void     *data;       // Item user data pointer
+  void     *data;       // User data pointer
   FXint     size;       // Item size
   FXint     pos;        // Item position
-  FXuint    state;      // Item state flags
+  FXuint    state;      // State flags
 private:
   FXHeaderItem(const FXHeaderItem&);
   FXHeaderItem& operator=(const FXHeaderItem&);
 protected:
   FXHeaderItem(){}
-  virtual void draw(const FXHeader* header,FXDC& dc,FXint x,FXint y,FXint w,FXint h);
+  virtual void draw(const FXHeader* header,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
 public:
   enum{
-    ARROW_NONE = 0,     /// No arrow
-    ARROW_UP   = 1,     /// Arrow pointing up
-    ARROW_DOWN = 2,     /// Arrow pointing down
-    PRESSED    = 4,     /// Pressed down
-    RIGHT      = 8,     /// Align on right
-    LEFT       = 16,    /// Align on left
-    CENTER_X   = 0,     /// Aling centered horizontally (default)
-    TOP        = 32,    /// Align on top
-    BOTTOM     = 64,    /// Align on bottom
-    CENTER_Y   = 0,     /// Aling centered vertically (default)
-    BEFORE     = 128,   /// Icon before the text
-    AFTER      = 256,   /// Icon after the text
-    ABOVE      = 512,   /// Icon above the text
-    BELOW      = 1024   /// Icon below the text
+    ARROW_NONE = 0,             /// No arrow
+    ARROW_UP   = 0x00000001,    /// Arrow pointing up
+    ARROW_DOWN = 0x00000002,    /// Arrow pointing down
+    PRESSED    = 0x00000004,    /// Pressed down
+    ICONOWNED  = 0x00000008,    /// Icon owned by header item
+    RIGHT      = 0x00000010,    /// Align on right
+    LEFT       = 0x00000020,    /// Align on left
+    CENTER_X   = 0,             /// Aling centered horizontally (default)
+    TOP        = 0x00000040,    /// Align on top
+    BOTTOM     = 0x00000080,    /// Align on bottom
+    CENTER_Y   = 0,             /// Aling centered vertically (default)
+    BEFORE     = 0x00000100,    /// Icon before the text
+    AFTER      = 0x00000200,    /// Icon after the text
+    ABOVE      = 0x00000400,    /// Icon above the text
+    BELOW      = 0x00000800     /// Icon below the text
     };
 public:
 
   /// Construct new item with given text, icon, size, and user-data
-  FXHeaderItem(const FXString& text,FXIcon* ic=NULL,FXint s=0,void* ptr=NULL):label(text),icon(ic),data(ptr),size(s),pos(0),state(LEFT|BEFORE){}
+  FXHeaderItem(const FXString& text,FXIcon* ic=NULL,FXint s=0,void* ptr=NULL);
 
   /// Change item's text label
   virtual void setText(const FXString& txt);
@@ -91,8 +90,14 @@ public:
   /// Return item's text label
   const FXString& getText() const { return label; }
 
-  /// Change item's icon
-  virtual void setIcon(FXIcon* icn);
+  /// Set the tool tip message for this item
+  void setTipText(const FXString& text){ tip=text; }
+
+  /// Get the tool tip message for this item
+  const FXString& getTipText() const { return tip; }
+
+  /// Change item's icon, deleting the old icon if it was owned
+  virtual void setIcon(FXIcon* icn,FXbool owned=false);
 
   /// Return item's icon
   FXIcon* getIcon() const { return icon; }
@@ -115,29 +120,29 @@ public:
   /// Obtain current position
   FXint getPos() const { return pos; }
 
-  /// Change sort direction (FALSE, TRUE, MAYBE)
-  void setArrowDir(FXbool dir=MAYBE);
+  /// Change sort direction (ARROW_NONE, ARROW_UP, ARROW_DOWN)
+  void setArrowDir(FXuint dir=ARROW_NONE);
 
-  /// Return sort direction (FALSE, TRUE, MAYBE)
-  FXbool getArrowDir() const;
+  /// Return sort direction (ARROW_NONE, ARROW_UP, ARROW_DOWN)
+  FXuint getArrowDir() const;
 
   /// Change content justification
   void setJustify(FXuint justify=LEFT|CENTER_Y);
 
   /// Return content justification
-  FXuint getJustify() const { return state&(RIGHT|LEFT|TOP|BOTTOM); }
+  FXuint getJustify() const;
 
   /// Change icon position
   void setIconPosition(FXuint mode=BEFORE);
 
   /// Return icon position
-  FXuint getIconPosition() const { return state&(BEFORE|AFTER|ABOVE|BELOW); }
+  FXuint getIconPosition() const;
 
   /// Change state to pressed
   void setPressed(FXbool pressed);
 
   /// Return pressed state
-  FXbool isPressed() const { return (state&PRESSED)!=0; }
+  FXbool isPressed() const;
 
   /// Return the item's content width in the header
   virtual FXint getWidth(const FXHeader* header) const;
@@ -158,11 +163,16 @@ public:
   virtual void save(FXStream& store) const;
   virtual void load(FXStream& store);
 
-  /// Destructor
-  virtual ~FXHeaderItem(){}
+  /// Delete item and free icon if owned
+  virtual ~FXHeaderItem();
   };
 
 
+/// Header item numbering function
+typedef FXString (*FXNumberingFunc)(FXint);
+
+
+/// List of FXHeaderItem's
 typedef FXObjectListOf<FXHeaderItem> FXHeaderItemList;
 
 
@@ -189,9 +199,10 @@ class FXAPI FXHeader : public FXFrame {
   FXDECLARE(FXHeader)
 protected:
   FXHeaderItemList items;	// Item list
-  FXColor          textColor;	// Text color
   FXFont          *font;	// Text font
+  FXNumberingFunc  numbering;   // Automatic caption renumbering method
   FXString         help;	// Help text
+  FXColor          textColor;	// Text color
   FXint            pos;		// Scroll position
   FXint            active;	// Active button
   FXint            activepos;	// Position of active item
@@ -215,6 +226,13 @@ public:
   long onQueryHelp(FXObject*,FXSelector,void*);
 public:
 
+  /// Generate numbers 1, 2, 3, ... as a function of index 0,1,2,...
+  static FXString decimalNumbering(FXint index);
+
+  /// Generate letters A, B, C, ... as a function of index 0,1,2,...
+  static FXString alphaNumbering(FXint index);
+public:
+
   /// Construct new header control
   FXHeader(FXComposite* p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=HEADER_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_PAD,FXint pr=DEFAULT_PAD,FXint pt=DEFAULT_PAD,FXint pb=DEFAULT_PAD);
 
@@ -256,43 +274,46 @@ public:
   FXHeaderItem *getItem(FXint index) const;
 
   /// Replace the item with a [possibly subclassed] item
-  FXint setItem(FXint index,FXHeaderItem* item,FXbool notify=FALSE);
+  FXint setItem(FXint index,FXHeaderItem* item,FXbool notify=false);
 
   /// Replace items text, icon, and user-data pointer
-  FXint setItem(FXint index,const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint setItem(FXint index,const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Fill header by appending items from array of strings
-  FXint fillItems(const FXchar** strings,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint fillItems(const FXchar *const *strings,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
+
+  /// Fill header by appending items from array of strings
+  FXint fillItems(const FXString* strings,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Fill header by appending items from newline separated strings
-  FXint fillItems(const FXString& strings,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint fillItems(const FXString& strings,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Insert a new [possibly subclassed] item at the give index
-  FXint insertItem(FXint index,FXHeaderItem* item,FXbool notify=FALSE);
+  FXint insertItem(FXint index,FXHeaderItem* item,FXbool notify=false);
 
   /// Insert item at index with given text, icon, and user-data pointer
-  FXint insertItem(FXint index,const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint insertItem(FXint index,const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Append a [possibly subclassed] item to the list
-  FXint appendItem(FXHeaderItem* item,FXbool notify=FALSE);
+  FXint appendItem(FXHeaderItem* item,FXbool notify=false);
 
   /// Append new item with given text and optional icon, and user-data pointer
-  FXint appendItem(const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint appendItem(const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Prepend a [possibly subclassed] item to the list
-  FXint prependItem(FXHeaderItem* item,FXbool notify=FALSE);
+  FXint prependItem(FXHeaderItem* item,FXbool notify=false);
 
   /// Prepend new item with given text and optional icon, and user-data pointer
-  FXint prependItem(const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=FALSE);
+  FXint prependItem(const FXString& text,FXIcon *icon=NULL,FXint size=0,void* ptr=NULL,FXbool notify=false);
 
   /// Extract item from list
-  FXHeaderItem* extractItem(FXint index,FXbool notify=FALSE);
+  FXHeaderItem* extractItem(FXint index,FXbool notify=false);
 
   /// Remove item at index
-  void removeItem(FXint index,FXbool notify=FALSE);
+  void removeItem(FXint index,FXbool notify=false);
 
   /// Remove all items
-  void clearItems(FXbool notify=FALSE);
+  void clearItems(FXbool notify=false);
 
   /// Change text label for item at index
   void setItemText(FXint index,const FXString& text);
@@ -300,8 +321,14 @@ public:
   /// Get text of item at index
   FXString getItemText(FXint index) const;
 
+  /// Change tool tip message for item at index
+  void setItemTipText(FXint index,const FXString& text);
+
+  /// Get tool tip message of item at index
+  FXString getItemTipText(FXint index) const;
+
   /// Change icon of item at index
-  void setItemIcon(FXint index,FXIcon* icon);
+  void setItemIcon(FXint index,FXIcon* icon,FXbool owned=false);
 
   /// Return icon of item at index
   FXIcon* getItemIcon(FXint index) const;
@@ -321,11 +348,11 @@ public:
   /// Return data of item at index
   void* getItemData(FXint index) const;
 
-  /// Change sort direction (FALSE, TRUE, MAYBE)
-  void setArrowDir(FXint index,FXbool dir=MAYBE);
+  /// Change sort direction (ARROW_NONE, ARROW_UP, ARROW_DOWN)
+  void setArrowDir(FXint index,FXuint dir=FXHeaderItem::ARROW_NONE);
 
-  /// Return sort direction (FALSE, TRUE, MAYBE)
-  FXbool getArrowDir(FXint index) const;
+  /// Return sort direction (ARROW_NONE, ARROW_UP, ARROW_DOWN)
+  FXuint getArrowDir(FXint index) const;
 
   /**
   * Change item justification.  Horizontal justification is controlled by passing
@@ -352,9 +379,9 @@ public:
   FXuint getItemIconPosition(FXint index) const;
 
   /// Changed button item's pressed state
-  void setItemPressed(FXint index,FXbool pressed=TRUE);
+  void setItemPressed(FXint index,FXbool pressed=true);
 
-  /// Return TRUE if button item is pressed in
+  /// Return true if button item is pressed in
   FXbool isItemPressed(FXint index) const;
 
   /// Scroll to make given item visible
@@ -369,12 +396,21 @@ public:
   /// return text font
   FXFont* getFont() const { return font; }
 
-  /// Return text color
-  FXColor getTextColor() const { return textColor; }
+  /// Manually renumber captions between fm and to inclusively
+  void renumberCaptions(FXNumberingFunc func,FXint fm=0,FXint to=2147483647);
+
+  /// Enable auto-renumbering using the given function, or disable it if NULL
+  void setAutoNumbering(FXNumberingFunc func);
+
+  /// Return auto-renumbering function
+  FXNumberingFunc getAutoNumbering() const { return numbering; }
 
   /// Change text color
   void setTextColor(FXColor clr);
 
+  /// Return text color
+  FXColor getTextColor() const { return textColor; }
+
   /// Set header style options
   void setHeaderStyle(FXuint style);
 
@@ -382,7 +418,7 @@ public:
   FXuint getHeaderStyle() const;
 
   /// Set the status line help text for this header
-  void setHelpText(const FXString& text);
+  void setHelpText(const FXString& text){ help=text; }
 
   /// Get the status line help text for this header
   const FXString& getHelpText() const { return help; }
