@@ -3,23 +3,20 @@
 *                          I C O   I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2014 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXICOImage.h,v 1.17 2005/01/16 16:06:06 fox Exp $                        *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXICOIMAGE_H
 #define FXICOIMAGE_H
@@ -40,6 +37,7 @@ private:
   FXICOImage &operator=(const FXICOImage&);
 public:
   static const FXchar fileExt[];
+  static const FXchar mimeType[];
 public:
 
   /// Construct image from memory stream formatted in Microsoft icon format
@@ -60,11 +58,10 @@ public:
 #define FXLOADICO
 
 /**
-* Check if stream contains a ICO, return TRUE if so.
+* Check if stream contains a ICO, return true if so.
 */
 extern FXAPI FXbool fxcheckICO(FXStream& store);
 
-
 /**
 * Load an ICO (Microsoft icon format) file from a stream.
 * Upon successful return, the pixel array and size are returned.
@@ -72,7 +69,6 @@ extern FXAPI FXbool fxcheckICO(FXStream& store);
 */
 extern FXAPI FXbool fxloadICO(FXStream& store,FXColor*& data,FXint& width,FXint& height,FXint& xspot,FXint& yspot);
 
-
 /**
 * Save an ICO (Microsoft icon format) file to a stream.
 * If no hot-spot given, save as an ICO instead of a CUR resource.
