@@ -3,23 +3,20 @@
 *                             I m a g e    O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXImage.h,v 1.61 2005/01/16 16:06:06 fox Exp $                           *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXIMAGE_H
 #define FXIMAGE_H
@@ -41,7 +38,8 @@ enum {
   IMAGE_ALPHACOLOR = 0x00000010,      /// Override transparancy color
   IMAGE_SHMI       = 0x00000020,      /// Using shared memory image
   IMAGE_SHMP       = 0x00000040,      /// Using shared memory pixmap
-  IMAGE_ALPHAGUESS = 0x00000080       /// Guess transparency color from corners
+  IMAGE_ALPHAGUESS = 0x00000080,      /// Guess transparency color from corners
+  IMAGE_THRESGUESS = 0x00000100       /// Guess threshold for etch mask
   };
 
 
@@ -56,6 +54,15 @@ class FXDCWindow;
 * compatible with the screen, for fast drawing onto the device.
 * The server-side representation is not directly accessible from the current
 * process as it lives in the process of the X Server or GDI.
+* Before the image can be used in drawing operations, the server-side representation
+* of the image must be realized by calling create(); until this is done, only the
+* client-side pixel buffer exists.
+* Usually the client-side pixel buffer is released when the server-side representation
+* is generated [thus saving substantial amounts of memory when only the server-resident
+* part of the image is of interest].  But if further manipulation of the client-side
+* pixel buffer is needed, the IMAGE_KEEP option can be passed.  In that case, the
+* client-side buffer can be modified, and the server-side pixmap can be updated by
+* calling render().
 */
 class FXAPI FXImage : public FXDrawable {
   FXDECLARE(FXImage)
@@ -68,8 +75,7 @@ private:
 #ifdef WIN32
   virtual FXID GetDC() const;
   virtual int ReleaseDC(FXID) const;
-#endif
-#ifndef WIN32
+#else
   void render_true_32(void *xim,FXuchar *img);
   void render_true_24(void *xim,FXuchar *img);
   void render_true_16_fast(void *xim,FXuchar *img);
@@ -115,6 +121,12 @@ public:
   /// To get to the option flags
   FXuint getOptions() const { return options; }
 
+  /// Set pixel data ownership flag
+  void setOwned(FXbool owned);
+
+  /// Get pixel data ownership flag
+  FXbool isOwned() const;
+
   /**
   * Populate the image with new pixel data of the same size; it will assume
   * ownership of the pixel data if image IMAGE_OWNED option is passed.
@@ -140,7 +152,7 @@ public:
   /// Change pixel at x,y
   void setPixel(FXint x,FXint y,FXColor color){ data[y*width+x]=color; }
 
-  /// Scan the image and return FALSE if fully opaque
+  /// Scan the image and return false if fully opaque
   FXbool hasAlpha() const;
 
   /**
@@ -167,7 +179,7 @@ public:
 
   /**
   * Retrieves pixels from the server-side image.  For example, to make
-  * screen snapshots, or to retrieve an image after it has been drawin
+  * screen snapshots, or to retrieve an image after it has been drawn
   * into by various means.
   */
   virtual void restore();
@@ -249,11 +261,11 @@ public:
   /// Blend image over uniform color
   virtual void blend(FXColor color);
 
-  /// Save object to stream
-  virtual void save(FXStream& store) const;
+  /// Invert colors of an image
+  virtual void invert();
 
-  /// Load object from stream
-  virtual void load(FXStream& store);
+  /// Colorize image based on luminance
+  virtual void colorize(FXColor color);
 
   /// Save pixel data only
   virtual FXbool savePixels(FXStream& store) const;
@@ -261,6 +273,12 @@ public:
   /// Load pixel data only
   virtual FXbool loadPixels(FXStream& store);
 
+  /// Save object to stream
+  virtual void save(FXStream& store) const;
+
+  /// Load object from stream
+  virtual void load(FXStream& store);
+
   /// Destructor
   virtual ~FXImage();
   };
