@@ -3,23 +3,20 @@
 *                         I n p u t   D i a l o g   B o x                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXInputDialog.h,v 1.15 2005/01/16 16:06:06 fox Exp $                     *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXINPUTDIALOG_H
 #define FXINPUTDIALOG_H
@@ -34,9 +31,9 @@ namespace FX {
 /// Input dialog options
 enum {
   INPUTDIALOG_STRING   = 0,             /// Ask for a string
-  INPUTDIALOG_INTEGER  = 0x01000000,    /// Ask for an integer number
-  INPUTDIALOG_REAL     = 0x02000000,    /// Ask for a real number
-  INPUTDIALOG_PASSWORD = 0x04000000     /// Do not reveal key-in
+  INPUTDIALOG_INTEGER  = 0x02000000,    /// Ask for an integer number
+  INPUTDIALOG_REAL     = 0x04000000,    /// Ask for a real number
+  INPUTDIALOG_PASSWORD = 0x08000000     /// Do not reveal key-in
   };
 
 
@@ -59,7 +56,7 @@ protected:
 private:
   FXInputDialog(const FXInputDialog&);
   FXInputDialog &operator=(const FXInputDialog&);
-  void initialize(const FXString& text,FXIcon* icon);
+  virtual void initialize(const FXString& text,FXIcon* icon);
 public:
   long onCmdAccept(FXObject*,FXSelector,void*);
 public:
@@ -93,7 +90,7 @@ public:
 
   /**
   * Prompt for a string, start with the initial value.
-  * Return TRUE if the new value is accepted, and false otherwise.
+  * Return true if the new value is accepted, and false otherwise.
   */
   static FXbool getString(FXString& result,FXWindow* owner,const FXString& caption,const FXString& label,FXIcon* icon=NULL);
 
@@ -104,29 +101,27 @@ public:
 
   /**
   * Prompt for an integer number, start with the given initial value.
-  * Return TRUE if the new value is accepted, and false otherwise.
-  * The input is constrained between lo and hi, unless lo>hi, in which
-  * case the input can be any number.
+  * Return true if the new value is accepted, and false otherwise.
+  * The input is constrained between lo and hi.
   */
-  static FXbool getInteger(FXint& result,FXWindow* owner,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXint lo=1,FXint hi=0);
+  static FXbool getInteger(FXint& result,FXWindow* owner,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXint lo=-2147483647,FXint hi=2147483647);
 
   /**
   * Prompt for a integer number, in free floating window.
   */
-  static FXbool getInteger(FXint& result,FXApp* app,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXint lo=1,FXint hi=0);
+  static FXbool getInteger(FXint& result,FXApp* app,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXint lo=-2147483647,FXint hi=2147483647);
 
   /**
   * Prompt for an real number, start with the given initial value.
-  * Return TRUE if the new value is accepted, and false otherwise.
-  * The input is constrained between lo and hi, unless lo>hi, in which
-  * case the input can be any number.
+  * Return true if the new value is accepted, and false otherwise.
+  * The input is constrained between lo and hi.
   */
-  static FXbool getReal(FXdouble& result,FXWindow* owner,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXdouble lo=1.0,FXdouble hi=0.0);
+  static FXbool getReal(FXdouble& result,FXWindow* owner,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXdouble lo=-1.797693134862315e+308,FXdouble hi=1.797693134862315e+308);
 
   /**
   * Prompt for a real number, in free floating window.
   */
-  static FXbool getReal(FXdouble& result,FXApp* app,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXdouble lo=1.0,FXdouble hi=0.0);
+  static FXbool getReal(FXdouble& result,FXApp* app,const FXString& caption,const FXString& label,FXIcon* icon=NULL,FXdouble lo=-1.797693134862315e+308,FXdouble hi=1.797693134862315e+308);
   };
 
 }
