@@ -3,23 +3,20 @@
 *         M u l t i p l e   D o c u m e n t   C l i e n t   W i n d o w         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXMDIClient.h,v 1.31 2005/01/16 16:06:06 fox Exp $                       *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXMDICLIENT_H
 #define FXMDICLIENT_H
@@ -50,20 +47,24 @@ class FXMDIChild;
 * A MDI Window selection dialog can be brought up through the ID_MDI_OVER_X messages;
 * a menu button connected to the MDI client with the ID_MDI_OVER_X message will be
 * automatically grayed out if there are less than X MDI child windows.
+* The ID_MDI_ANY may be connected to a menu separator to cause automatic hiding of the
+* menu separator when no MDI child windows are present.
 */
 class FXAPI FXMDIClient : public FXComposite {
   FXDECLARE(FXMDIClient)
   friend class FXMDIChild;
 protected:
-  FXMDIChild *active;             // Active child
-  FXint       cascadex;           // Cascade offset X
-  FXint       cascadey;           // Cascade offset Y
+  FXMDIChild *active;           // Active child
+  FXImage    *backImage;        // Optional background image
+  FXint       cascadex;         // Cascade offset X
+  FXint       cascadey;         // Cascade offset Y
 protected:
   FXMDIClient();
 private:
   FXMDIClient(const FXMDIClient&);
   FXMDIClient &operator=(const FXMDIClient&);
 public:
+  long onPaint(FXObject*,FXSelector,void*);
   long onCmdActivateNext(FXObject*,FXSelector,void*);
   long onCmdActivatePrev(FXObject*,FXSelector,void*);
   long onCmdTileHorizontal(FXObject*,FXSelector,void*);
@@ -118,6 +119,9 @@ public:
   /// Construct MDI Client window
   FXMDIClient(FXComposite* p,FXuint opts=0,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
+  /// Create window
+  virtual void create();
+
   /// Return default width
   virtual FXint getDefaultWidth();
 
@@ -146,19 +150,28 @@ public:
   long forallDocWindows(FXObject* document,FXObject* sender,FXSelector sel,void* ptr);
 
   /// Set active MDI Child
-  virtual FXbool setActiveChild(FXMDIChild* child=NULL,FXbool notify=TRUE);
+  virtual FXbool setActiveChild(FXMDIChild* child=NULL,FXbool notify=true);
 
   /// Get current active child; may be NULL!
   FXMDIChild* getActiveChild() const { return active; }
 
+  /// Get active document; this is the target of the active MDI Child, if any
+  FXObject* getActiveDocument() const;
+
+  /// Change background image
+  void setBackImage(FXImage* img);
+
+  /// Return background image
+  FXImage* getBackImage() const { return backImage; }
+
   /// Cascade windows
-  virtual void cascade(FXbool notify=FALSE);
+  virtual void cascade(FXbool notify=false);
 
   /// Layout horizontally
-  virtual void horizontal(FXbool notify=FALSE);
+  virtual void horizontal(FXbool notify=false);
 
   /// Layout vertically
-  virtual void vertical(FXbool notify=FALSE);
+  virtual void vertical(FXbool notify=false);
 
   /// Change cascade offset X
   void setCascadeX(FXint off){ cascadex=off; }
