@@ -3,23 +3,20 @@
 *                         M e n u C a p t i o n   W i d g e t                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXMenuCaption.h,v 1.28 2004/02/08 17:17:33 fox Exp $                     *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXMENUCAPTION_H
 #define FXMENUCAPTION_H
@@ -43,14 +40,21 @@ class FXFont;
 
 
 /**
-* The menu caption is a widget which can be used as a caption
-* above a number of menu commands in a menu.
+* The menu caption is a widget which can be used as a caption above a number
+* of menu commands in a menu.
+* When passing a tab-separated list of fields in the text parameter, the caption
+* text is set to the first field, and the help string to the third field.
+* If the caption text contains an ampersand, the letter following it will be
+* underlined, and a suitable hotkey will be installed.  The actual ampersand
+* will be removed.
+* To display an ampersand in the caption, use two consecutive ampersands.
 */
 class FXAPI FXMenuCaption : public FXWindow {
   FXDECLARE(FXMenuCaption)
 protected:
   FXString     label;
   FXString     help;
+  FXString     tip;
   FXIcon      *icon;
   FXFont      *font;
   FXint        hotoff;
@@ -68,13 +72,17 @@ private:
 public:
   long onPaint(FXObject*,FXSelector,void*);
   long onUpdate(FXObject*,FXSelector,void*);
+  long onCmdSetValue(FXObject*,FXSelector,void*);
   long onCmdGetStringValue(FXObject*,FXSelector,void*);
   long onCmdSetStringValue(FXObject*,FXSelector,void*);
   long onCmdSetIconValue(FXObject*,FXSelector,void*);
   long onCmdGetIconValue(FXObject*,FXSelector,void*);
   long onCmdSetHelp(FXObject*,FXSelector,void*);
   long onCmdGetHelp(FXObject*,FXSelector,void*);
+  long onCmdSetTip(FXObject*,FXSelector,void*);
+  long onCmdGetTip(FXObject*,FXSelector,void*);
   long onQueryHelp(FXObject*,FXSelector,void*);
+  long onQueryTip(FXObject*,FXSelector,void*);
 public:
 
   /// Construct a menu caption
@@ -122,24 +130,24 @@ public:
   /// Get menu caption style
   FXuint getMenuStyle() const;
 
-  /// Get the current text color
-  FXColor getTextColor() const { return textColor; }
-
   /// Return the current text color
   void setTextColor(FXColor clr);
 
-  /// Return the selection background color
-  FXColor getSelBackColor() const { return selbackColor; }
+  /// Get the current text color
+  FXColor getTextColor() const { return textColor; }
 
   /// Return the selection background color
   void setSelBackColor(FXColor clr);
 
-  /// Return the selection text color
-  FXColor getSelTextColor() const { return seltextColor; }
+  /// Return the selection background color
+  FXColor getSelBackColor() const { return selbackColor; }
 
   /// Return the selection text color
   void setSelTextColor(FXColor clr);
 
+  /// Return the selection text color
+  FXColor getSelTextColor() const { return seltextColor; }
+
   /// Change highlight color
   void setHiliteColor(FXColor clr);
 
@@ -156,7 +164,13 @@ public:
   void setHelpText(const FXString& text);
 
   /// Get the status line help text for this menu
-  FXString getHelpText() const { return help; }
+  const FXString& getHelpText() const { return help; }
+
+  /// Set the tool tip message for this menu
+  void setTipText(const FXString& text){ tip=text; }
+
+  /// Get the tool tip message for this menu
+  const FXString& getTipText() const { return tip; }
 
   /// Save menu to a stream
   virtual void save(FXStream& store) const;
