@@ -3,23 +3,20 @@
 *                       M e n u C o m m a n d   W i d g e t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXMenuCommand.h,v 1.27 2005/01/16 16:06:06 fox Exp $                     *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXMENUCOMMAND_H
 #define FXMENUCOMMAND_H
@@ -35,6 +32,14 @@ namespace FX {
 * The menu command widget is used to invoke a command in the
 * application from a menu.  Menu commands may reflect
 * the state of the application by graying out, or becoming hidden.
+* When activated, a menu command sends a SEL_COMMAND to its target.
+* When passing a tab-separated list of fields in the text parameters, the caption
+* text is set to the first field, the accelerator to the second field, and the
+* help text to the third field (see description of menu caption).
+* If an accelerator string is given, the corresponding accelerator key combination
+* is parsed out and installed into the menu pane's owner's accelerator table.
+* Note that this means owners of menu panes should delete their menupanes properly
+* upon destruction.
 */
 class FXAPI FXMenuCommand : public FXMenuCaption {
   FXDECLARE(FXMenuCommand)
@@ -77,8 +82,8 @@ public:
   /// Remove the focus from this window
   virtual void killFocus();
 
-  /// Set accelerator text
-  void setAccelText(const FXString& text);
+  /// Set accelerator text; update accelerator if acc is true
+  void setAccelText(const FXString& text,FXbool acc=false);
 
   /// Return accelarator text
   FXString getAccelText() const { return accel; }
