@@ -3,23 +3,20 @@
 *                    M e n u   S e p a r a t o r   W i d g e t                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXMenuSeparator.h,v 1.16 2005/01/16 16:06:06 fox Exp $                   *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXMENUSEPARATOR_H
 #define FXMENUSEPARATOR_H
@@ -32,8 +29,13 @@ namespace FX {
 
 
 /**
-* The menu separator is a simple decorative groove
-* used to delineate items in a popup menu.
+* The menu separator is a simple decorative groove used to delineate items in a
+* popup menu.  When a target/message is given, the menu separator is usually
+* connected to an instance of the recent files class using the ID_ANYFILES
+* message.  This automatically hides the menu separator when no files are listed
+* in the recent files section.  Another possible target is the MDI client using
+* the ID_MDI_ANY message: in this case, the menu separator will be automatically
+* hidden when no MDI child windows are present.
 */
 class FXAPI FXMenuSeparator : public FXWindow {
   FXDECLARE(FXMenuSeparator)
@@ -50,7 +52,7 @@ public:
 public:
 
   /// Construct a menu separator
-  FXMenuSeparator(FXComposite* p,FXuint opts=0);
+  FXMenuSeparator(FXComposite* p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=0);
 
   /// Return default width
   virtual FXint getDefaultWidth();
