@@ -3,23 +3,20 @@
 *                             O p t i o n   M e n u                             *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXOptionMenu.h,v 1.23 2004/02/08 17:17:34 fox Exp $                      *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXOPTIONMENU_H
 #define FXOPTIONMENU_H
@@ -34,11 +31,21 @@ namespace FX {
 class FXPopup;
 
 
+/// Option Menu Button flags
+enum {
+  OPTIONMENU_TOOLBAR   = 0x00800000,  /// Toolbar style button [flat look]
+  OPTIONMENU_NOGLYPH   = 0x01000000,  /// Do not display a glyph
+  };
+
+
 /// Option Menu Button
 class FXAPI FXOption : public FXLabel {
   FXDECLARE(FXOption)
 protected:
-  FXOption(){}
+  FXColor selbackColor;
+  FXColor seltextColor;
+protected:
+  FXOption();
 private:
   FXOption(const FXOption&);
   FXOption &operator=(const FXOption&);
@@ -72,6 +79,18 @@ public:
   /// Remove the focus from this window
   virtual void killFocus();
 
+  /// Return the selection background color
+  void setSelBackColor(FXColor clr);
+
+  /// Return the selection background color
+  FXColor getSelBackColor() const { return selbackColor; }
+
+  /// Return the selection text color
+  void setSelTextColor(FXColor clr);
+
+  /// Return the selection text color
+  FXColor getSelTextColor() const { return seltextColor; }
+
   /// Destructor
   virtual ~FXOption();
   };
@@ -93,6 +112,8 @@ public:
   long onPaint(FXObject*,FXSelector,void*);
   long onLeftBtnPress(FXObject*,FXSelector,void*);
   long onLeftBtnRelease(FXObject*,FXSelector,void*);
+  long onEnter(FXObject*,FXSelector,void*);
+  long onLeave(FXObject*,FXSelector,void*);
   long onFocusIn(FXObject*,FXSelector,void*);
   long onFocusOut(FXObject*,FXSelector,void*);
   long onMotion(FXObject*,FXSelector,void*);
@@ -105,6 +126,7 @@ public:
   long onCmdSetValue(FXObject*,FXSelector,void*);
   long onCmdSetIntValue(FXObject*,FXSelector,void*);
   long onCmdGetIntValue(FXObject*,FXSelector,void*);
+  long onMouseWheel(FXObject*,FXSelector,void*);
 public:
 
   /// Constructor
@@ -131,17 +153,20 @@ public:
   /// Return default height
   virtual FXint getDefaultHeight();
 
-  /// Return TRUE if the position is logically in the pane
+  /// Return true if the position is logically in the pane
   virtual FXbool contains(FXint parentx,FXint parenty) const;
 
+  /// Return the option item at the given index
+  FXOption *getItem(FXint index) const;
+
   /// Set the current option
-  void setCurrent(FXOption *win,FXbool notify=FALSE);
+  void setCurrent(FXOption *win,FXbool notify=false);
 
   /// Return the current option
   FXOption* getCurrent() const { return current; }
 
   /// Set the current option number
-  void setCurrentNo(FXint no,FXbool notify=FALSE);
+  void setCurrentNo(FXint no,FXbool notify=false);
 
   /// Get the current option number
   FXint getCurrentNo() const;
@@ -158,7 +183,7 @@ public:
   /// Returns true because a option menu can receive focus
   virtual FXbool canFocus() const;
 
-  /// Return TRUE if popped up
+  /// Return true if popped up
   FXbool isPopped() const;
 
   /// Save option menu to a stream
