@@ -3,23 +3,20 @@
 *                        P C X   I c o n   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2004 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2014 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXPCXIcon.h,v 1.12 2004/02/08 17:17:34 fox Exp $                         *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXPCXICON_H
 #define FXPCXICON_H
@@ -39,6 +36,9 @@ private:
   FXPCXIcon(const FXPCXIcon&);
   FXPCXIcon &operator=(const FXPCXIcon&);
 public:
+  static const FXchar fileExt[];
+  static const FXchar mimeType[];
+public:
 
   /// Construct icon from memory stream formatted in PCX file format
   FXPCXIcon(FXApp* a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
@@ -54,6 +54,15 @@ public:
   };
 
 
+#ifndef FXLOADPCX
+#define FXLOADPCX
+
+/**
+* Check if stream contains a PCX, return true if so.
+*/
+extern FXAPI FXbool fxcheckPCX(FXStream& store);
+
+
 /**
 * Load an PCX (PC Paintbrush) file from a stream.
 * Upon successful return, the pixel array and size are returned.
@@ -67,6 +76,8 @@ extern FXAPI FXbool fxloadPCX(FXStream& store,FXColor*& data,FXint& width,FXint&
 */
 extern FXAPI FXbool fxsavePCX(FXStream& store,const FXColor *data,FXint width,FXint height);
 
+#endif
+
 }
 
 #endif
