@@ -3,23 +3,20 @@
 *          D o u b l e - P r e c i s i o n    R a n g e    C l a s s            *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXRanged.h,v 1.9.2.1 2006/03/21 07:08:29 fox Exp $                           *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXRANGED_H
 #define FXRANGED_H
@@ -29,6 +26,7 @@ namespace FX {
 
 
 class FXSphered;
+class FXMat4d;
 
 
 /// Bounds
@@ -38,17 +36,23 @@ public:
   FXVec3d upper;
 public:
 
-  /// Default constructor
+  /// Default constructor; value is not initialized
   FXRanged(){}
 
-  /// Copy constructor
+  /// Initialize with another range
   FXRanged(const FXRanged& bounds):lower(bounds.lower),upper(bounds.upper){}
 
-  /// Initialize from two vectors
-  FXRanged(const FXVec3d& lo,const FXVec3d& hi):lower(lo),upper(hi){}
+  /// Initialize with a single point
+  FXRanged(const FXVec3d& p):lower(p),upper(p){}
 
-  /// Initialize from six numbers
-  FXRanged(FXdouble xlo,FXdouble xhi,FXdouble ylo,FXdouble yhi,FXdouble zlo,FXdouble zhi):lower(xlo,ylo,zlo),upper(xhi,yhi,zhi){}
+  /// Initialize with corner points
+  FXRanged(const FXVec3d& l,const FXVec3d& h):lower(l),upper(h){}
+
+  /// Initialize with a single point
+  FXRanged(FXdouble x,FXdouble y,FXdouble z):lower(x,y,z),upper(x,y,z){}
+
+  /// Initialize with explicit values
+  FXRanged(FXdouble xl,FXdouble xh,FXdouble yl,FXdouble yh,FXdouble zl,FXdouble zh):lower(xl,yl,zl),upper(xh,yh,zh){}
 
   /// Initialize box to fully contain the given bounding sphere
   FXRanged(const FXSphered& sphere);
@@ -56,12 +60,31 @@ public:
   /// Assignment
   FXRanged& operator=(const FXRanged& bounds){ lower=bounds.lower; upper=bounds.upper; return *this; }
 
+  /// Set value from another range
+  FXRanged& set(const FXRanged& bounds){ lower=bounds.lower; upper=bounds.upper; return *this; }
+
+  /// Set value from single point
+  FXRanged& set(const FXVec3d& p){ lower=upper=p; return *this; }
+
+  /// Set value from corner points
+  FXRanged& set(const FXVec3d& l,const FXVec3d& h){ lower=l; upper=h; return *this; }
+
+  /// Set value from single point
+  FXRanged& set(FXdouble x,FXdouble y,FXdouble z){ lower.x=upper.x=x; lower.y=upper.y=y; lower.z=upper.z=z; return *this; }
+
+  /// Set value from explicit values
+  FXRanged& set(FXdouble xl,FXdouble xh,FXdouble yl,FXdouble yh,FXdouble zl,FXdouble zh){ lower.set(xl,yl,zl); upper.set(xh,yh,zh); return *this; }
+
   /// Indexing with 0..1
   FXVec3d& operator[](FXint i){ return (&lower)[i]; }
 
   /// Indexing with 0..1
   const FXVec3d& operator[](FXint i) const { return (&lower)[i]; }
 
+  /// Comparison
+  FXbool operator==(const FXRanged& r) const { return lower==r.lower && upper==r.upper; }
+  FXbool operator!=(const FXRanged& r) const { return lower!=r.lower || upper!=r.upper; }
+
   /// Width of box
   FXdouble width() const { return upper.x-lower.x; }
 
@@ -71,6 +94,12 @@ public:
   /// Depth of box
   FXdouble depth() const { return upper.z-lower.z; }
 
+  /// Area of box
+  FXdouble area() const { return (width()*height()+width()*depth()+height()*depth())*2.0; }
+
+  /// Volume of box
+  FXdouble volume() const { return width()*height()*depth(); }
+
   /// Longest side
   FXdouble longest() const;
 
@@ -80,6 +109,9 @@ public:
   /// Length of diagonal
   FXdouble diameter() const;
 
+  /// Get radius of box
+  FXdouble radius() const;
+
   /// Compute diagonal
   FXVec3d diagonal() const;
 
@@ -117,32 +149,35 @@ public:
   FXint intersect(const FXVec4d &plane) const;
 
   /// Intersect box with ray u-v
-  FXbool intersect(const FXVec3d& u,const FXVec3d& v);
+  FXbool intersect(const FXVec3d& u,const FXVec3d& v) const;
 
-  /// Test if bounds overlap
-  friend FXAPI FXbool overlap(const FXRanged& a,const FXRanged& b);
+  /// Intersect box with ray pos+lambda*dir, returning true if hit
+  FXbool intersect(const FXVec3d& pos,const FXVec3d& dir,FXdouble hit[]) const;
 
   /// Get corner number 0..7
   FXVec3d corner(FXint c) const { return FXVec3d((&lower)[c&1].x, (&lower)[(c>>1)&1].y, (&lower)[c>>2].z); }
 
-  /// Union of two boxes
-  friend FXAPI FXRanged unite(const FXRanged& a,const FXRanged& b);
+  /// Transform range by 4x4 matrix
+  FXRanged transform(const FXMat4d& mat) const;
 
-  /// Intersection of two boxes
-  friend FXAPI FXRanged intersect(const FXRanged& a,const FXRanged& b);
-
-  /// Save object to a stream
-  friend FXAPI FXStream& operator<<(FXStream& store,const FXRanged& bounds);
-
-  /// Load object from a stream
-  friend FXAPI FXStream& operator>>(FXStream& store,FXRanged& bounds);
+  /// Destructor
+ ~FXRanged(){}
   };
 
 
+/// Test if boxes a and b overlap
 extern FXAPI FXbool overlap(const FXRanged& a,const FXRanged& b);
+
+/// Union of two boxes
 extern FXAPI FXRanged unite(const FXRanged& a,const FXRanged& b);
+
+/// Intersection of two boxes
 extern FXAPI FXRanged intersect(const FXRanged& a,const FXRanged& b);
+
+/// Save object to a stream
 extern FXAPI FXStream& operator<<(FXStream& store,const FXRanged& bounds);
+
+/// Load object from a stream
 extern FXAPI FXStream& operator>>(FXStream& store,FXRanged& bounds);
 
 }
