@@ -3,23 +3,20 @@
 *                       R e a l S l i d e r   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXRealSlider.h,v 1.7 2005/01/16 16:06:06 fox Exp $                       *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXREALSLIDER_H
 #define FXREALSLIDER_H
@@ -60,17 +57,18 @@ enum {
 class FXAPI FXRealSlider : public FXFrame {
   FXDECLARE(FXRealSlider)
 protected:
-  FXdouble      range[2];                 // Reported data range
-  FXdouble      pos;                      // Reported data position
-  FXdouble      incr;                     // Increment when auto-sliding
-  FXdouble      delta;                    // Interval between ticks
-  FXint         headpos;                  // Head position
-  FXint         headsize;                 // Head size
-  FXint         slotsize;                 // Slot size
-  FXColor       slotColor;                // Color of slot the head moves in
-  FXint         dragpoint;                // Where on the head is grabbed
-  FXString      help;                     // Help string
-  FXString      tip;                      // Tip string
+  FXint         headPos;        // Head position
+  FXint         headSize;       // Head size
+  FXint         slotSize;       // Slot size
+  FXColor       slotColor;      // Color of slot the head moves in
+  FXint         dragPoint;      // Where on the head is grabbed
+  FXdouble      range[2];       // Reported data range
+  FXdouble      delta;          // Interval between ticks
+  FXdouble      incr;           // Increment when auto-sliding
+  FXdouble      gran;           // Granularity
+  FXdouble      pos;            // Reported data position
+  FXString      help;           // Help string
+  FXString      tip;            // Tip string
 protected:
   FXRealSlider();
   void drawSliderHead(FXDCWindow& dc,FXint x,FXint y,FXint w,FXint h);
@@ -81,17 +79,21 @@ private:
   FXRealSlider &operator=(const FXRealSlider&);
 public:
   long onPaint(FXObject*,FXSelector,void*);
+  long onMotion(FXObject*,FXSelector,void*);
+  long onMouseWheel(FXObject*,FXSelector,void*);
   long onLeftBtnPress(FXObject*,FXSelector,void*);
   long onLeftBtnRelease(FXObject*,FXSelector,void*);
   long onMiddleBtnPress(FXObject*,FXSelector,void*);
   long onMiddleBtnRelease(FXObject*,FXSelector,void*);
-  long onMouseWheel(FXObject*,FXSelector,void*);
+  long onKeyPress(FXObject*,FXSelector,void*);
+  long onKeyRelease(FXObject*,FXSelector,void*);
   long onUngrabbed(FXObject*,FXSelector,void*);
-  long onMotion(FXObject*,FXSelector,void*);
   long onAutoSlide(FXObject*,FXSelector,void*);
   long onCmdSetValue(FXObject*,FXSelector,void*);
   long onCmdSetIntValue(FXObject*,FXSelector,void*);
   long onCmdGetIntValue(FXObject*,FXSelector,void*);
+  long onCmdSetLongValue(FXObject*,FXSelector,void*);
+  long onCmdGetLongValue(FXObject*,FXSelector,void*);
   long onCmdSetRealValue(FXObject*,FXSelector,void*);
   long onCmdGetRealValue(FXObject*,FXSelector,void*);
   long onCmdSetIntRange(FXObject*,FXSelector,void*);
@@ -120,6 +122,9 @@ public:
   /// Return default height
   virtual FXint getDefaultHeight();
 
+  /// Returns true because a slider can receive focus
+  virtual FXbool canFocus() const;
+
   /// Perform layout
   virtual void layout();
 
@@ -130,13 +135,13 @@ public:
   virtual void disable();
 
   /// Change slider value
-  void setValue(FXdouble value);
+  void setValue(FXdouble value,FXbool notify=false);
 
   /// Return slider value
   FXdouble getValue() const { return pos; }
 
   /// Change the slider's range
-  void setRange(FXdouble lo,FXdouble hi);
+  void setRange(FXdouble lo,FXdouble hi,FXbool notify=false);
 
   /// Get the slider's current range
   void getRange(FXdouble& lo,FXdouble& hi) const { lo=range[0]; hi=range[1]; }
@@ -148,13 +153,13 @@ public:
   void setSliderStyle(FXuint style);
 
   /// Get the slider's head size
-  FXint getHeadSize() const { return headsize; }
+  FXint getHeadSize() const { return headSize; }
 
   /// Change the slider's head size
   void setHeadSize(FXint hs);
 
   /// Get the slider's current slot size
-  FXint getSlotSize() const { return slotsize; }
+  FXint getSlotSize() const { return slotSize; }
 
   /// Change the slider's slot size
   void setSlotSize(FXint bs);
@@ -165,6 +170,12 @@ public:
   /// Change the slider's auto-increment/decrement value
   void setIncrement(FXdouble inc);
 
+  /// Change slider's granularity
+  void setGranularity(FXdouble gr);
+
+  /// Return slider's granularity
+  FXdouble getGranularity() const { return gran; }
+
   /// Change the delta between ticks
   void setTickDelta(FXdouble dist);
 
