@@ -3,23 +3,20 @@
 *           S i n g l e - P r e c i s i o n    S p h e r e    C l a s s         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2004,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXSpheref.h,v 1.10.2.1 2006/03/21 07:08:29 fox Exp $                          *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXSPHEREF_H
 #define FXSPHEREF_H
@@ -29,6 +26,7 @@ namespace FX {
 
 
 class FXRangef;
+class FXMat4f;
 
 
 /// Spherical bounds
@@ -38,7 +36,7 @@ public:
   FXfloat radius;
 public:
 
-  /// Default constructor
+  /// Default constructor; value is not initialized
   FXSpheref(){}
 
   /// Copy constructor
@@ -56,9 +54,28 @@ public:
   /// Assignment
   FXSpheref& operator=(const FXSpheref& sphere){ center=sphere.center; radius=sphere.radius; return *this; }
 
+  /// Set value from another sphere
+  FXSpheref& set(const FXSpheref& sphere){ center=sphere.center; radius=sphere.radius; return *this; }
+
+  /// Set value from center and radius
+  FXSpheref& set(const FXVec3f& cen,FXfloat rad=0.0f){ center=cen; radius=rad; return *this; }
+
+  /// Set value from center and radius
+  FXSpheref& set(FXfloat x,FXfloat y,FXfloat z,FXfloat rad=0.0f){ center.set(x,y,z); radius=rad; return *this; }
+
+  /// Comparison
+  FXbool operator==(const FXSpheref& s) const { return center==s.center && radius==s.radius;}
+  FXbool operator!=(const FXSpheref& s) const { return center!=s.center || radius!=s.radius;}
+
   /// Diameter of sphere
   FXfloat diameter() const { return radius*2.0f; }
 
+  /// Area of sphere
+  FXfloat area() const { return radius*radius*12.5663706143591729538505735331f; }
+
+  /// Volume of sphere
+  FXfloat volume() const { return radius*radius*radius*4.18879020478639098461685784437f; }
+
   /// Test if empty
   FXbool empty() const { return radius<0.0f; }
 
@@ -80,40 +97,54 @@ public:
   /// Include point
   FXSpheref& include(const FXVec3f& p);
 
+  /// Expand radius to include point
+  FXSpheref& includeInRadius(FXfloat x,FXfloat y,FXfloat z);
+
+  /// Expand radius to include point
+  FXSpheref& includeInRadius(const FXVec3f& p);
+
   /// Include given range into this one
   FXSpheref& include(const FXRangef& box);
 
+  /// Expand radius to include box
+  FXSpheref& includeInRadius(const FXRangef& box);
+
   /// Include given sphere into this one
   FXSpheref& include(const FXSpheref& sphere);
 
+  /// Expand radius to include sphere
+  FXSpheref& includeInRadius(const FXSpheref& sphere);
+
   /// Intersect sphere with normalized plane ax+by+cz+w; returns -1,0,+1
   FXint intersect(const FXVec4f& plane) const;
 
   /// Intersect sphere with ray u-v
   FXbool intersect(const FXVec3f& u,const FXVec3f& v) const;
 
-  /// Test if box overlaps with sphere
-  friend FXAPI FXbool overlap(const FXRangef& a,const FXSpheref& b);
+  /// Intersect box with ray pos+lambda*dir, returning true if hit
+  FXbool intersect(const FXVec3f& pos,const FXVec3f& dir,FXfloat hit[]) const;
 
-  /// Test if sphere overlaps with box
-  friend FXAPI FXbool overlap(const FXSpheref& a,const FXRangef& b);
+  /// Transform sphere by 4x4 matrix
+  FXSpheref transform(const FXMat4f& mat) const;
 
-  /// Test if spheres overlap
-  friend FXAPI FXbool overlap(const FXSpheref& a,const FXSpheref& b);
-
-  /// Save object to a stream
-  friend FXAPI FXStream& operator<<(FXStream& store,const FXSpheref& sphere);
-
-  /// Load object from a stream
-  friend FXAPI FXStream& operator>>(FXStream& store,FXSpheref& sphere);
+  /// Destructor
+ ~FXSpheref(){}
   };
 
 
+/// Test if box overlaps with sphere
 extern FXAPI FXbool overlap(const FXRangef& a,const FXSpheref& b);
+
+/// Test if sphere overlaps with box
 extern FXAPI FXbool overlap(const FXSpheref& a,const FXRangef& b);
+
+/// Test if spheres overlap
 extern FXAPI FXbool overlap(const FXSpheref& a,const FXSpheref& b);
 
+/// Save object to a stream
 extern FXAPI FXStream& operator<<(FXStream& store,const FXSpheref& sphere);
+
+/// Load object from a stream
 extern FXAPI FXStream& operator>>(FXStream& store,FXSpheref& sphere);
 
 }
