@@ -3,23 +3,20 @@
 *                       T A R G A  I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2014 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTGAImage.h,v 1.15 2005/01/16 16:06:06 fox Exp $                        *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTGAIMAGE_H
 #define FXTGAIMAGE_H
@@ -41,6 +38,7 @@ private:
   FXTGAImage &operator=(const FXTGAImage&);
 public:
   static const FXchar fileExt[];
+  static const FXchar mimeType[];
 public:
 
   /// Construct image from memory stream formatted in TARGA file
@@ -57,8 +55,11 @@ public:
   };
 
 
+#ifndef FXLOADTGA
+#define FXLOADTGA
+
 /**
-* Check if stream contains a TARGA, return TRUE if so.
+* Check if stream contains a TARGA, return true if so.
 */
 extern FXAPI FXbool fxcheckTGA(FXStream& store);
 
@@ -76,6 +77,8 @@ extern FXAPI FXbool fxloadTGA(FXStream& store,FXColor*& data,FXint& width,FXint&
 */
 extern FXAPI FXbool fxsaveTGA(FXStream& store,const FXColor *data,FXint width,FXint height);
 
+#endif
+
 }
 
 #endif
