@@ -3,23 +3,20 @@
 *                          T I F F   I c o n   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 Eric Gillet.   All Rights Reserved.                   *
+* Copyright (C) 2001,2014 Eric Gillet.   All Rights Reserved.                   *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTIFIcon.h,v 1.19 2005/01/16 16:06:06 fox Exp $                         *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTIFICON_H
 #define FXTIFICON_H
@@ -43,11 +40,15 @@ private:
   FXTIFIcon &operator=(const FXTIFIcon&);
 public:
   static const FXchar fileExt[];
+  static const FXchar mimeType[];
 public:
 
   /// Construct an icon from memory stream formatted in TIFF format
   FXTIFIcon(FXApp *a,const void *pix=NULL,FXColor clr=FXRGB(192,192,192),FXuint opts=0,FXint w=1,FXint h=1);
 
+  /// True if format is supported
+  static const FXbool supported;
+
   /// Set codec to save with
   void setCodec(FXuint c){ codec=c; }
 
@@ -60,16 +61,16 @@ public:
   /// Load pixels from stream in TIFF format
   virtual FXbool loadPixels(FXStream& store);
 
-  /// True if format is supported
-  static const FXbool supported;
-
   /// Destroy
   virtual ~FXTIFIcon();
   };
 
 
+#ifndef FXLOADTIF
+#define FXLOADTIF
+
 /**
-* Check if stream contains a TIFF, return TRUE if so.
+* Check if stream contains a TIFF, return true if so.
 */
 extern FXAPI FXbool fxcheckTIF(FXStream& store);
 
@@ -87,6 +88,8 @@ extern FXAPI FXbool fxloadTIF(FXStream& store,FXColor*& data,FXint& width,FXint&
 */
 extern FXAPI FXbool fxsaveTIF(FXStream& store,const FXColor* data,FXint width,FXint height,FXushort codec);
 
+#endif
+
 }
 
 #endif
