@@ -1,25 +1,22 @@
 /********************************************************************************
 *                                                                               *
-*                           T a b  B a r   W i d g e t                          *
+*                          T a b   B a r   W i d g e t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTabBar.h,v 1.10 2005/01/16 16:06:06 fox Exp $                           *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTABBAR_H
 #define FXTABBAR_H
@@ -49,11 +46,16 @@ enum {
 * In a the horizontal arrangement, the tab bar can have the tab
 * items on the top or on the bottom.  In the vertical arrangement,
 * the tabs can be on the left or on the right.
+* When one of the tab items is pressed, the tab bar's setCurrent()
+* is called with notify=true.  Thus causes the tab bar to send a
+* SEL_COMMAND message to its target, with the currently active
+* tab index in the void pointer.
 */
 class FXAPI FXTabBar : public FXPacker {
   FXDECLARE(FXTabBar)
 protected:
   FXint current;        // Current tab index
+  FXint shift;          // Shift amount
 protected:
   FXTabBar(){}
 private:
@@ -104,11 +106,12 @@ public:
   virtual void layout();
 
   /**
-  * Change currently active tab item;
-  * this raises the active tab item slightly above the neighboring
-  * tab items.
+  * Change currently active tab item; this raises the active tab item
+  * slightly above the neighboring tab items.  If notify=true then the
+  * tab bar will also send a SEL_COMMAND message to its target, containing
+  * the currently active tab index in the void pointer.
   */
-  virtual void setCurrent(FXint panel,FXbool notify=FALSE);
+  virtual void setCurrent(FXint index,FXbool notify=false);
 
   /// Return the currently active tab item
   FXint getCurrent() const { return current; }
