@@ -3,23 +3,20 @@
 *                         T a b   B o o k   W i d g e t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTabBook.h,v 1.10 2006/01/22 17:58:10 fox Exp $                          *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTABBOOK_H
 #define FXTABBOOK_H
@@ -44,8 +41,9 @@ namespace FX {
 * in a small space by placing several panels on top of each
 * other and using tab items to select the desired panel.
 * When one of the tab items is pressed, the tab book's setCurrent()
-* is called with notify=TRUE.  Thus causes the tab book to send a
-* SEL_COMMAND message to its target.
+* is called with notify=true.  Thus causes the tab book to send a
+* SEL_COMMAND message to its target, with the currently active
+* tab index in the void pointer.
 */
 class FXAPI FXTabBook : public FXTabBar {
   FXDECLARE(FXTabBook)
@@ -68,6 +66,14 @@ public:
   /// Construct tab book
   FXTabBook(FXComposite* p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=TABBOOK_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0,FXint pl=DEFAULT_SPACING,FXint pr=DEFAULT_SPACING,FXint pt=DEFAULT_SPACING,FXint pb=DEFAULT_SPACING);
 
+  /**
+  * Change currently active tab item; this raises the active tab item
+  * slightly above the neighboring tab items.  If notify=true then the
+  * tab bar will also send a SEL_COMMAND message to its target, containing
+  * the currently active tab index in the void pointer.
+  */
+  virtual void setCurrent(FXint index,FXbool notify=false);
+
   /// Perform layout
   virtual void layout();
 
