@@ -1,25 +1,22 @@
 /********************************************************************************
 *                                                                               *
-*                       T o o l B a r G r i p   W i d g e t                     *
+*                    T o o l   B a r   G r i p   W i d g e t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXToolBarGrip.h,v 1.17 2005/02/04 03:41:00 fox Exp $                     *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTOOLBARGRIP_H
 #define FXTOOLBARGRIP_H
@@ -73,10 +70,13 @@ public:
   /// Return default height
   virtual FXint getDefaultHeight();
 
-  /// Change toolbar grip to double
-  void setDoubleBar(FXbool dbl=TRUE);
+  /// The grip can not receive the focus
+  virtual FXbool canFocus() const;
 
-  /// Return TRUE if toolbar grip is displayed as a double bar
+  /// Change toolbar grip to double
+  void setDoubleBar(FXbool dbl=true);
+
+  /// Return true if toolbar grip is displayed as a double bar
   FXbool isDoubleBar() const;
 
   /// Set the active color
