@@ -3,23 +3,20 @@
 *                 T o p - L e v e l   W i n d o w   W i d g e t                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTopWindow.h,v 1.57.2.1 2005/10/25 11:33:11 fox Exp $                       *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTOPWINDOW_H
 #define FXTOPWINDOW_H
@@ -50,12 +47,20 @@ enum {
 
 /// Initial window placement
 enum {
-  PLACEMENT_DEFAULT,                  /// Place it at the default size and location
-  PLACEMENT_VISIBLE,                  /// Place window to be fully visible
-  PLACEMENT_CURSOR,                   /// Place it under the cursor position
-  PLACEMENT_OWNER,                    /// Place it centered on its owner
-  PLACEMENT_SCREEN,                   /// Place it centered on the screen
-  PLACEMENT_MAXIMIZED                 /// Place it maximized to the screen size
+  PLACEMENT_DEFAULT,            /// Place it at the default size and location
+  PLACEMENT_VISIBLE,            /// Place window to be fully visible
+  PLACEMENT_CURSOR,             /// Place it under the cursor position
+  PLACEMENT_OWNER,              /// Place it centered on its owner
+  PLACEMENT_SCREEN,             /// Place it centered on the screen
+  PLACEMENT_MAXIMIZED           /// Place it maximized to the screen size
+  };
+
+
+/// Special stacking orders
+enum {
+  STACK_NORMAL,                 /// Stack normally (default)
+  STACK_BOTTOM,                 /// Stack below other windows
+  STACK_TOP                     /// Stack above other windows
   };
 
 
@@ -63,7 +68,6 @@ class FXToolBar;
 class FXIcon;
 
 
-
 /**
 * Abstract base class for all top-level windows.
 * TopWindows are usually managed by a Window Manager under X11 and
@@ -75,6 +79,12 @@ class FXIcon;
 * there is no objection to proceed with the closing of the window, and
 * return 1 otherwise.  After the SEL_CLOSE message has been sent and
 * no objection was raised, the window will delete itself.
+* When the session is closed, the window will send a SEL_SESSION_NOTIFY
+* message to its target, allowing the application to write any unsaved
+* data to the disk.  If the target returns 0, then the system will proceed
+* to close the session.  Subsequently a SEL_SESSION_CLOSED will be received
+* which causes the window to be closed with prejudice by calling the
+* function close(false).
 * When receiving a SEL_UPDATE, the target can update the title string
 * of the window, so that the title of the window reflects the name
 * of the document, for example.
@@ -97,10 +107,8 @@ protected:
   FXint     padright;                 // Right margin
   FXint     hspacing;                 // Horizontal child spacing
   FXint     vspacing;                 // Vertical child spacing
-  FXint     offx;
-  FXint     offy;
 protected:
-  FXTopWindow(){}
+  FXTopWindow();
   void settitle();
   void seticons();
   void setdecorations();
@@ -110,17 +118,22 @@ private:
   FXTopWindow(const FXTopWindow&);
   FXTopWindow& operator=(const FXTopWindow&);
 #ifdef WIN32
-  virtual const char* GetClass() const;
-  static void* makeicon(FXIcon* icon);
+  virtual const void* GetClass() const;
 #endif
 public:
   long onFocusUp(FXObject*,FXSelector,void*);
   long onFocusDown(FXObject*,FXSelector,void*);
   long onFocusLeft(FXObject*,FXSelector,void*);
   long onFocusRight(FXObject*,FXSelector,void*);
+  long onSessionNotify(FXObject*,FXSelector,void*);
+  long onSessionClosed(FXObject*,FXSelector,void*);
+  long onRestore(FXObject*,FXSelector,void*);
+  long onMaximize(FXObject*,FXSelector,void*);
+  long onMinimize(FXObject*,FXSelector,void*);
+  long onCmdRestore(FXObject*,FXSelector,void*);
   long onCmdMaximize(FXObject*,FXSelector,void*);
   long onCmdMinimize(FXObject*,FXSelector,void*);
-  long onCmdRestore(FXObject*,FXSelector,void*);
+  long onCmdFullScreen(FXObject*,FXSelector,void*);
   long onCmdClose(FXObject*,FXSelector,void*);
   long onCmdSetStringValue(FXObject*,FXSelector,void*);
   long onCmdGetStringValue(FXObject*,FXSelector,void*);
@@ -128,9 +141,10 @@ public:
   long onCmdGetIconValue(FXObject*,FXSelector,void*);
 public:
   enum {
-    ID_MAXIMIZE=FXShell::ID_LAST,       /// Maximize the window
+    ID_RESTORE=FXShell::ID_LAST,        /// Restore the window
+    ID_MAXIMIZE,                        /// Maximize the window
     ID_MINIMIZE,                        /// Minimize the window
-    ID_RESTORE,                         /// Restore the window
+    ID_FULLSCREEN,                      /// Make the window full screen
     ID_CLOSE,                           /// Close the window
     ID_QUERY_DOCK,                      /// Toolbar asks to dock
     ID_LAST
@@ -143,6 +157,9 @@ public:
   /// Detach the server-side resources for this window
   virtual void detach();
 
+  /// Destroy the server-side resources for this window
+  virtual void destroy();
+
   /// Perform layout
   virtual void layout();
 
@@ -176,6 +193,9 @@ public:
   /// Raise this window to the top of the stacking order
   virtual void raise();
 
+  /// Lower this window to the bottom of the stacking order
+  virtual void lower();
+
   /// Move this window to the specified position in the parent's coordinates
   virtual void move(FXint x,FXint y);
 
@@ -185,24 +205,42 @@ public:
   /// Move and resize this window in the parent's coordinates
   virtual void position(FXint x,FXint y,FXint w,FXint h);
 
-  /// Maximize window, return TRUE if maximized
-  virtual FXbool maximize(FXbool notify=FALSE);
+  /// Flash the window to get user's attention
+  virtual void flash(FXbool yes);
 
-  /// Minimize or iconify window, return TRUE if minimized
-  virtual FXbool minimize(FXbool notify=FALSE);
+  /// Restore window to normal, return true if restored
+  virtual FXbool restore(FXbool notify=false);
 
-  /// Restore window to normal, return TRUE if restored
-  virtual FXbool restore(FXbool notify=FALSE);
+  /// Maximize window, return true if maximized
+  virtual FXbool maximize(FXbool notify=false);
 
-  /// Close the window, return TRUE if actually closed
-  virtual FXbool close(FXbool notify=FALSE);
+  /// Minimize or iconify window, return true if minimized
+  virtual FXbool minimize(FXbool notify=false);
 
-  /// Return TRUE if maximized
+  /// Make window full screen, return true if success
+  virtual FXbool fullScreen(FXbool notify=false);
+
+  /// Special stacking order level
+  virtual FXbool stackingOrder(FXuint order);
+
+  /**
+  * Close the window, return true if actually closed.  If notify=true, the target
+  * will receive a SEL_CLOSE message to determine if it is OK to close the window.
+  * If the target ignores the SEL_CLOSE message or returns 0, the window will
+  * be closed, and subsequently deleted.  When the last main window has been
+  * closed, the application will receive an ID_QUIT message and will be closed.
+  */
+  virtual FXbool close(FXbool notify=false);
+
+  /// Return true if maximized
   FXbool isMaximized() const;
 
-  /// Return TRUE if minimized
+  /// Return true if minimized
   FXbool isMinimized() const;
 
+  /// Return true if full screen
+  FXbool isFullScreen() const;
+
   /// Change window title
   void setTitle(const FXString& name);
 
