@@ -3,23 +3,20 @@
 *                         T r e e   L i s t   W i d g e t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXTreeList.h,v 1.78 2004/03/15 16:05:28 fox Exp $                        *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXTREELIST_H
 #define FXTREELIST_H
@@ -57,37 +54,40 @@ class FXAPI FXTreeItem : public FXObject {
   friend class FXTreeList;
   friend class FXDirList;
 protected:
-  FXTreeItem *parent;
-  FXTreeItem *prev;
-  FXTreeItem *next;
-  FXTreeItem *first;
-  FXTreeItem *last;
-  FXString    label;
-  FXIcon     *openIcon;
-  FXIcon     *closedIcon;
-  void       *data;
-  FXuint      state;
+  FXTreeItem *parent;           // Parent item
+  FXTreeItem *prev;             // Previous item
+  FXTreeItem *next;             // Next item
+  FXTreeItem *first;            // First child item
+  FXTreeItem *last;             // Last child item
+  FXString    label;            // Text of item
+  FXIcon     *openIcon;         // Icon of item
+  FXIcon     *closedIcon;       // Icon of item
+  FXptr       data;             // Item user data pointer
+  FXuint      state;            // Item state flags
   FXint       x,y;
+private:
+  FXTreeItem(const FXTreeItem&);
+  FXTreeItem& operator=(const FXTreeItem&);
 protected:
   FXTreeItem():parent(NULL),prev(NULL),next(NULL),first(NULL),last(NULL),openIcon(NULL),closedIcon(NULL),data(NULL),state(0),x(0),y(0){}
   virtual void draw(const FXTreeList* list,FXDC& dc,FXint x,FXint y,FXint w,FXint h) const;
   virtual FXint hitItem(const FXTreeList* list,FXint x,FXint y) const;
-protected:
+public:
   enum{
-    SELECTED        = 1,
-    FOCUS           = 2,
-    DISABLED        = 4,
-    OPENED          = 8,
-    EXPANDED        = 16,
-    HASITEMS        = 32,
-    DRAGGABLE       = 64,
-    OPENICONOWNED   = 128,
-    CLOSEDICONOWNED = 256
+    SELECTED        = 1,        /// Selected
+    FOCUS           = 2,        /// Focus
+    DISABLED        = 4,        /// Disabled
+    OPENED          = 8,        /// Opened
+    EXPANDED        = 16,       /// Expanded
+    HASITEMS        = 32,       /// Has virtual subitems
+    DRAGGABLE       = 64,       /// Draggable
+    OPENICONOWNED   = 128,      /// Open icon owned by item
+    CLOSEDICONOWNED = 256       /// Close icon owned by item
     };
 public:
 
   /// Constructor
-  FXTreeItem(const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL):parent(NULL),prev(NULL),next(NULL),first(NULL),last(NULL),label(text),openIcon(oi),closedIcon(ci),data(ptr),state(0),x(0),y(0){}
+  FXTreeItem(const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL):parent(NULL),prev(NULL),next(NULL),first(NULL),last(NULL),label(text),openIcon(oi),closedIcon(ci),data(ptr),state(0),x(0),y(0){}
 
   /// Get parent item
   FXTreeItem* getParent() const { return parent; }
@@ -114,28 +114,28 @@ public:
   FXint getNumChildren() const;
 
   /// Change item label
-  virtual void setText(const FXString& txt){ label=txt; }
+  virtual void setText(const FXString& txt);
 
   /// Get item label
   const FXString& getText() const { return label; }
 
-  /// Change open icon
-  virtual void setOpenIcon(FXIcon* icn){ openIcon=icn; }
+  /// Change open icon, deleting the old icon if it was owned
+  virtual void setOpenIcon(FXIcon* icn,FXbool owned=false);
 
   /// Get open icon
   FXIcon* getOpenIcon() const { return openIcon; }
 
-  /// Change closed icon
-  virtual void setClosedIcon(FXIcon* icn){ closedIcon=icn; }
+  /// Change closed icon, deleting the old icon if it was owned
+  virtual void setClosedIcon(FXIcon* icn,FXbool owned=false);
 
   /// Get closed icon
   FXIcon* getClosedIcon() const { return closedIcon; }
 
   /// Change item user data
-  void setData(void* ptr){ data=ptr; }
+  void setData(FXptr ptr){ data=ptr; }
 
   /// Get item user data
-  void* getData() const { return data; }
+  FXptr getData() const { return data; }
 
   /// Make item draw as focused
   virtual void setFocus(FXbool focus);
@@ -173,24 +173,21 @@ public:
   /// Return true if this item is draggable
   FXbool isDraggable() const { return (state&DRAGGABLE)!=0; }
 
-  /// Make open and or icon owned by the item
-  void setIconOwned(FXuint owned=(OPENICONOWNED|CLOSEDICONOWNED));
-
-  /// Return open icon and closed icon ownership status
-  FXuint isIconOwned() const { return (state&(OPENICONOWNED|CLOSEDICONOWNED)); }
-
-  /// Return TRUE if subitems, real or imagined
+  /// Return true if subitems, real or imagined
   FXbool hasItems() const { return (state&HASITEMS)!=0; }
-  
+
   /// Change has items flag
   void setHasItems(FXbool flag);
-  
+
   /// Return true if descendent of parent item
   FXbool isChildOf(const FXTreeItem* item) const;
 
   /// Return true if ancestor of child item
   FXbool isParentOf(const FXTreeItem* item) const;
 
+  /// Return tip text
+  virtual FXString getTipText() const;
+
   /// Return width of item as drawn in list
   virtual FXint getWidth(const FXTreeList* list) const;
 
@@ -251,7 +248,7 @@ protected:
   FXTreeItem        *anchoritem;        // Selection anchor item
   FXTreeItem        *currentitem;       // Current item
   FXTreeItem        *extentitem;        // Selection extent
-  FXTreeItem        *cursoritem;        // Item under cursor
+  FXTreeItem        *viewableitem;      // Visible item
   FXFont            *font;              // Font
   FXTreeListSortFunc sortfunc;          // Item sort function
   FXColor            textColor;         // Text color
@@ -265,11 +262,12 @@ protected:
   FXint              grabx;             // Grab point x
   FXint              graby;             // Grab point y
   FXString           lookup;            // Lookup string
+  FXString           tip;
   FXString           help;              // Help string
   FXbool             state;             // State of item
 protected:
   FXTreeList();
-  virtual FXTreeItem* createItem(const FXString& text,FXIcon* oi,FXIcon* ci,void* ptr);
+  virtual FXTreeItem* createItem(const FXString& text,FXIcon* oi,FXIcon* ci,FXptr ptr);
   void sort(FXTreeItem*& f1,FXTreeItem*& t1,FXTreeItem*& f2,FXTreeItem*& t2,int n);
   void recompute();
 private:
@@ -361,47 +359,50 @@ public:
   /// Return last root item
   FXTreeItem* getLastItem() const { return lastitem; }
 
-  /// Prepend new [possibly subclassed] item as first child of p
-  FXTreeItem* addItemFirst(FXTreeItem* p,FXTreeItem* item,FXbool notify=FALSE);
+  /// Fill tree list by appending items from array of strings
+  FXint fillItems(FXTreeItem* father,const FXchar *const *strings,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  /// Prepend new item with given text and optional icon, and user-data pointer as first child of p
-  FXTreeItem* addItemFirst(FXTreeItem* p,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL,FXbool notify=FALSE);
+  /// Fill tree list by appending items from array of strings
+  FXint fillItems(FXTreeItem* father,const FXString* strings,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  /// Append new [possibly subclassed] item as last child of p
-  FXTreeItem* addItemLast(FXTreeItem* p,FXTreeItem* item,FXbool notify=FALSE);
+  /// Fill tree list by appending items from newline separated strings
+  FXint fillItems(FXTreeItem* father,const FXString& strings,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  /// Append new item with given text and optional icon, and user-data pointer as last child of p
-  FXTreeItem* addItemLast(FXTreeItem* p,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL,FXbool notify=FALSE);
+  /// Replace the original item orig with new [possibly subclassed] item
+  FXTreeItem* setItem(FXTreeItem* orig,FXTreeItem* item,FXbool notify=false);
 
-  /// Append new [possibly subclassed] item after to other item
-  FXTreeItem* addItemAfter(FXTreeItem* other,FXTreeItem* item,FXbool notify=FALSE);
+  /// Insert [possibly subclassed] item under father before other item
+  FXTreeItem* insertItem(FXTreeItem* other,FXTreeItem* father,FXTreeItem* item,FXbool notify=false);
 
-  /// Append new item with given text and optional icon, and user-data pointer after to other item
-  FXTreeItem* addItemAfter(FXTreeItem* other,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL,FXbool notify=FALSE);
+  /// Insert item with given text and optional icons, and user-data pointer under father before other item
+  FXTreeItem* insertItem(FXTreeItem* other,FXTreeItem* father,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  /// Prepend new [possibly subclassed] item prior to other item
-  FXTreeItem* addItemBefore(FXTreeItem* other,FXTreeItem* item,FXbool notify=FALSE);
+  /// Append [possibly subclassed] item as last child of father
+  FXTreeItem* appendItem(FXTreeItem* father,FXTreeItem* item,FXbool notify=false);
 
-  /// Prepend new item with given text and optional icon, and user-data pointer prior to other item
-  FXTreeItem* addItemBefore(FXTreeItem* other,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,void* ptr=NULL,FXbool notify=FALSE);
+  /// Append item with given text and optional icons, and user-data pointer as last child of father
+  FXTreeItem* appendItem(FXTreeItem* father,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  /// Reparent item under parent p
-  void reparentItem(FXTreeItem* item,FXTreeItem* p);
+  /// Prepend [possibly subclassed] item as first child of father
+  FXTreeItem* prependItem(FXTreeItem* father,FXTreeItem* item,FXbool notify=false);
 
-  // Move item before other
-  FXTreeItem* moveItemBefore(FXTreeItem* other,FXTreeItem* item);
+  /// Prepend item with given text and optional icons, and user-data pointer as first child of father
+  FXTreeItem* prependItem(FXTreeItem* father,const FXString& text,FXIcon* oi=NULL,FXIcon* ci=NULL,FXptr ptr=NULL,FXbool notify=false);
 
-  // Move item after other
-  FXTreeItem* moveItemAfter(FXTreeItem* other,FXTreeItem* item);
+  /// Move item under father before other item
+  FXTreeItem *moveItem(FXTreeItem* other,FXTreeItem* father,FXTreeItem* item);
+
+  /// Extract item
+  FXTreeItem* extractItem(FXTreeItem* item,FXbool notify=false);
 
   /// Remove item
-  void removeItem(FXTreeItem* item,FXbool notify=FALSE);
+  void removeItem(FXTreeItem* item,FXbool notify=false);
 
   /// Remove items in range [fm, to] inclusively
-  void removeItems(FXTreeItem* fm,FXTreeItem* to,FXbool notify=FALSE);
+  void removeItems(FXTreeItem* fm,FXTreeItem* to,FXbool notify=false);
 
   /// Remove all items from list
-  void clearItems(FXbool notify=FALSE);
+  void clearItems(FXbool notify=false);
 
   /// Return item width
   FXint getItemWidth(const FXTreeItem* item) const { return item->getWidth(this); }
@@ -410,16 +411,34 @@ public:
   FXint getItemHeight(const FXTreeItem* item) const { return item->getHeight(this); }
 
   /// Get item at x,y, if any
-  FXTreeItem* getItemAt(FXint x,FXint y) const;
+  virtual FXTreeItem* getItemAt(FXint x,FXint y) const;
 
-  /**
-  * Search items for item by name, starting from start item; the
-  * flags argument controls the search direction, and case sensitivity.
-  */
-  FXTreeItem* findItem(const FXString& text,FXTreeItem* start=NULL,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+  /// Return item hit code: 0 outside, 1 icon, 2 text, 3 box
+  FXint hitItem(const FXTreeItem* item,FXint x,FXint y) const;
 
   /// Scroll to make item visible
-  void makeItemVisible(FXTreeItem* item);
+  virtual void makeItemVisible(FXTreeItem* item);
+
+  /**
+  * Search items by name, beginning from item start.  If the start item
+  * is NULL the search will start at the first, top-most item in the list.
+  * Flags may be SEARCH_FORWARD or SEARCH_BACKWARD to control the search
+  * direction; this can be combined with SEARCH_NOWRAP or SEARCH_WRAP
+  * to control whether the search wraps at the start or end of the list.
+  * The option SEARCH_IGNORECASE causes a case-insensitive match.  Finally,
+  * passing SEARCH_PREFIX causes searching for a prefix of the item name.
+  * Return NULL if no matching item is found.
+  */
+  FXTreeItem* findItem(const FXString& name,FXTreeItem* start=NULL,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
+
+  /**
+  * Search items by associated user data, beginning from item start. If the
+  * start item is NULL the search will start at the first, top-most item
+  * in the list.  Flags may be SEARCH_FORWARD or SEARCH_BACKWARD to control
+  * the search direction; this can be combined with SEARCH_NOWRAP or SEARCH_WRAP
+  * to control whether the search wraps at the start or end of the list.
+  */
+  FXTreeItem* findItemByData(FXptr ptr,FXTreeItem* start=NULL,FXuint flags=SEARCH_FORWARD|SEARCH_WRAP) const;
 
   /// Change item's text
   void setItemText(FXTreeItem* item,const FXString& text);
@@ -428,13 +447,13 @@ public:
   FXString getItemText(const FXTreeItem* item) const;
 
   /// Change item's open icon
-  void setItemOpenIcon(FXTreeItem* item,FXIcon* icon);
+  void setItemOpenIcon(FXTreeItem* item,FXIcon* icon,FXbool owned=false);
 
-  /// Return item's open icon
+  /// Return item's open icon, deleting the old icon if it was owned
   FXIcon* getItemOpenIcon(const FXTreeItem* item) const;
 
-  /// Chance item's closed icon
-  void setItemClosedIcon(FXTreeItem* item,FXIcon* icon);
+  /// Chance item's closed icon, deleting the old icon if it was owned
+  void setItemClosedIcon(FXTreeItem* item,FXIcon* icon,FXbool owned=false);
 
   /// Return item's closed icon
   FXIcon* getItemClosedIcon(const FXTreeItem* item) const;
@@ -445,68 +464,68 @@ public:
   /// Return item user-data pointer
   void* getItemData(const FXTreeItem* item) const;
 
-  /// Return TRUE if item is selected
+  /// Return true if item is selected
   FXbool isItemSelected(const FXTreeItem* item) const;
 
-  /// Return TRUE if item is current
+  /// Return true if item is current
   FXbool isItemCurrent(const FXTreeItem* item) const;
 
-  /// Return TRUE if item is visible
+  /// Return true if item is visible
   FXbool isItemVisible(const FXTreeItem* item) const;
 
-  /// Return TRUE if item opened
+  /// Return true if item opened
   FXbool isItemOpened(const FXTreeItem* item) const;
 
-  /// Return TRUE if item expanded
+  /// Return true if item expanded
   FXbool isItemExpanded(const FXTreeItem* item) const;
 
-  /// Return TRUE if item is a leaf-item, i.e. has no children
+  /// Return true if item is a leaf-item, i.e. has no children
   FXbool isItemLeaf(const FXTreeItem* item) const;
 
-  /// Return TRUE if item is enabled
+  /// Return true if item is enabled
   FXbool isItemEnabled(const FXTreeItem* item) const;
 
-  /// Return item hit code: 0 outside, 1 icon, 2 text, 3 box
-  FXint hitItem(const FXTreeItem* item,FXint x,FXint y) const;
-
   /// Repaint item
   void updateItem(FXTreeItem* item) const;
 
   /// Enable item
-  FXbool enableItem(FXTreeItem* item);
+  virtual FXbool enableItem(FXTreeItem* item);
 
   /// Disable item
-  FXbool disableItem(FXTreeItem* item);
+  virtual FXbool disableItem(FXTreeItem* item);
 
   /// Select item
-  virtual FXbool selectItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool selectItem(FXTreeItem* item,FXbool notify=false);
 
   /// Deselect item
-  virtual FXbool deselectItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool deselectItem(FXTreeItem* item,FXbool notify=false);
 
   /// Toggle item selection
-  virtual FXbool toggleItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool toggleItem(FXTreeItem* item,FXbool notify=false);
 
   /// Extend selection from anchor item to item
-  virtual FXbool extendSelection(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool extendSelection(FXTreeItem* item,FXbool notify=false);
+
+  /// Select all items
+  virtual FXbool selectAll(FXbool notify=false);
 
   /// Deselect all items
-  virtual FXbool killSelection(FXbool notify=FALSE);
+  virtual FXbool killSelection(FXbool notify=false);
 
   /// Open item
-  virtual FXbool openItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool openItem(FXTreeItem* item,FXbool notify=false);
 
   /// Close item
-  virtual FXbool closeItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual FXbool closeItem(FXTreeItem* item,FXbool notify=false);
 
   /// Collapse tree
-  virtual FXbool collapseTree(FXTreeItem* tree,FXbool notify=FALSE);
+  virtual FXbool collapseTree(FXTreeItem* tree,FXbool notify=false);
 
   /// Expand tree
-  virtual FXbool expandTree(FXTreeItem* tree,FXbool notify=FALSE);
+  virtual FXbool expandTree(FXTreeItem* tree,FXbool notify=false);
 
   /// Change current item
-  virtual void setCurrentItem(FXTreeItem* item,FXbool notify=FALSE);
+  virtual void setCurrentItem(FXTreeItem* item,FXbool notify=false);
 
   /// Return current item, if any
   FXTreeItem* getCurrentItem() const { return currentitem; }
@@ -517,9 +536,6 @@ public:
   /// Return anchor item, if any
   FXTreeItem* getAnchorItem() const { return anchoritem; }
 
-  /// Return item under cursor, if any
-  FXTreeItem* getCursorItem() const { return cursoritem; }
-
   /// Sort all items recursively
   void sortItems();
 
@@ -581,7 +597,7 @@ public:
   void setHelpText(const FXString& text);
 
   /// Get the status line help text for this list
-  FXString getHelpText() const { return help; }
+  const FXString& getHelpText() const { return help; }
 
   /// Save object to a stream
   virtual void save(FXStream& store) const;
