@@ -3,23 +3,20 @@
 *                            W i n d o w   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2014 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This library is free software; you can redistribute it and/or                 *
-* modify it under the terms of the GNU Lesser General Public                    *
-* License as published by the Free Software Foundation; either                  *
-* version 2.1 of the License, or (at your option) any later version.            *
+* This library is free software; you can redistribute it and/or modify          *
+* it under the terms of the GNU Lesser General Public License as published by   *
+* the Free Software Foundation; either version 3 of the License, or             *
+* (at your option) any later version.                                           *
 *                                                                               *
 * This library is distributed in the hope that it will be useful,               *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of                *
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
-* Lesser General Public License for more details.                               *
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                 *
+* GNU Lesser General Public License for more details.                           *
 *                                                                               *
-* You should have received a copy of the GNU Lesser General Public              *
-* License along with this library; if not, write to the Free Software           *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: FXWindow.h,v 1.130 2005/02/02 16:37:40 fox Exp $                         *
+* You should have received a copy of the GNU Lesser General Public License      *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>          *
 ********************************************************************************/
 #ifndef FXWINDOW_H
 #define FXWINDOW_H
@@ -28,10 +25,20 @@
 #include "FXDrawable.h"
 #endif
 
-
 namespace FX {
 
 
+// Forward declarations
+class FXIcon;
+class FXBitmap;
+class FXCursor;
+class FXRegion;
+class FXDCWindow;
+class FXComposite;
+class FXAccelTable;
+class FXComposeContext;
+
+
 /// Layout hints for child widgets
 enum {
   LAYOUT_NORMAL      = 0,                                   /// Default layout mode
@@ -84,59 +91,88 @@ enum {
   };
 
 
-class FXIcon;
-class FXBitmap;
-class FXCursor;
-class FXRegion;
-class FXComposite;
-class FXAccelTable;
+/// Data exchange modes
+enum FXDNDOrigin {
+  FROM_SELECTION  = 0,              /// Primary selection
+  FROM_CLIPBOARD  = 1,              /// Clipboard
+  FROM_DRAGNDROP  = 2               /// Drag and drop source
+  };
 
 
-/// Base class for all windows
+/// Drag and drop actions
+enum FXDragAction {
+  DRAG_REJECT  = 0,             /// Reject all drop actions
+  DRAG_ASK     = 1,             /// Ask
+  DRAG_COPY    = 2,             /// Copy
+  DRAG_MOVE    = 3,             /// Move
+  DRAG_LINK    = 4,             /// Link
+  DRAG_PRIVATE = 5,             /// Private
+  DRAG_ACCEPT  = 6              /// Accept any drop action
+  };
+
+
+/**
+* Window is the base class for all widgets in FOX.
+* All widgets are organized in a tree structure, with a single root window
+* at the top.
+* Each window links to its parent window, next and previous siblings windows,
+* as well as its first and last child windows.  A window also has an owner window,
+* which is the window responsible for its creation and destruction.  In most cases,
+* the owner window will be the same as the parent window, except for top-level windows.
+* The focus window determines to which child keyboard messages are delegated if the
+* window is a composite window (i.e. if it has children).
+* Windows are geometrically arranged by their immediate parent window; the actual
+* method of placement is determined by the type of layout supported by the parent
+* window, as well as the window's layout hints.
+* The position of a window is determined relative to its immediate parent window;
+* A window can send a message to its target object when an event happens.
+*/
 class FXAPI FXWindow : public FXDrawable {
   FXDECLARE(FXWindow)
+  friend class FXApp;
 private:
-  FXWindow     *parent;                 // Parent Window
-  FXWindow     *owner;                  // Owner Window
-  FXWindow     *first;                  // First Child
-  FXWindow     *last;                   // Last Child
-  FXWindow     *next;                   // Next Sibling
-  FXWindow     *prev;                   // Previous Sibling
-  FXWindow     *focus;                  // Focus Child
-  FXuint        wk;                     // Window Key
+  FXWindow         *parent;             // Parent Window
+  FXWindow         *owner;              // Owner Window
+  FXWindow         *first;              // First Child
+  FXWindow         *last;               // Last Child
+  FXWindow         *next;               // Next Sibling
+  FXWindow         *prev;               // Previous Sibling
+  FXWindow         *focus;              // Focus Child
+  FXuint            wk;                 // Window Key
 protected:
-  FXCursor     *defaultCursor;          // Normal Cursor
-  FXCursor     *dragCursor;             // Cursor during drag
-  FXAccelTable *accelTable;             // Accelerator table
-  FXObject     *target;                 // Target object
-  FXSelector    message;                // Message ID
-  FXint         xpos;                   // Window X Position
-  FXint         ypos;                   // Window Y Position
-  FXColor       backColor;              // Window background color
-  FXString      tag;                    // Help tag
-  FXuint        flags;                  // Window state flags
-  FXuint        options;                // Window options
-private:
-  static FXint  windowCount;            // Number of windows
+  FXComposeContext *composeContext;     // Compose context
+  FXCursor         *defaultCursor;      // Normal Cursor
+  FXCursor         *dragCursor;         // Cursor during drag
+  FXAccelTable     *accelTable;         // Accelerator table
+  FXObject         *target;             // Target object
+  FXSelector        message;            // Message ID
+  FXint             xpos;               // Window X Position
+  FXint             ypos;               // Window Y Position
+  FXColor           backColor;          // Window background color
+  FXString          tag;                // Help tag
+  FXuint            flags;              // Window state flags
+  FXuint            options;            // Window options
 public:
-  static FXDragType deleteType;         // Delete request
-  static FXDragType textType;           // Ascii text request
-  static FXDragType colorType;          // Color
-  static FXDragType urilistType;        // URI List
+  static FXDragType       octetType;    // Raw octet stream
+  static FXDragType       deleteType;   // Delete request
+  static FXDragType       textType;     // Ascii text request
+  static FXDragType       colorType;    // Color request
+  static FXDragType       urilistType;  // URI list request
+  static FXDragType       utf8Type;     // UTF-8 text request
+  static FXDragType       utf16Type;    // UTF-16 text request
+  static FXDragType       actionType;   // Clipboard action
   static const FXDragType stringType;   // Clipboard text type (pre-registered)
   static const FXDragType imageType;    // Clipboard image type (pre-registered)
 protected:
   FXWindow();
   FXWindow(FXApp* a,FXVisual *vis);
   FXWindow(FXApp* a,FXWindow* own,FXuint opts,FXint x,FXint y,FXint w,FXint h);
-  static FXWindow* findDefault(FXWindow* window);
-  static FXWindow* findInitial(FXWindow* window);
   virtual FXbool doesOverrideRedirect() const;
 protected:
 #ifdef WIN32
   virtual FXID GetDC() const;
   virtual int ReleaseDC(FXID) const;
-  virtual const char* GetClass() const;
+  virtual const void* GetClass() const;
 #else
   void addColormapWindows();
   void remColormapWindows();
@@ -170,7 +206,28 @@ protected:
     FLAG_DODRAG       = 0x00080000,     // Doing drag mode
     FLAG_SCROLLINSIDE = 0x00100000,     // Scroll only when inside
     FLAG_SCROLLING    = 0x00200000,     // Right mouse scrolling
-    FLAG_OWNED        = 0x00400000      // Window handle owned by widget
+    FLAG_OWNED        = 0x00400000,     // Owned window handle
+    FLAG_CURSOR       = 0x00800000      // Showing cursor
+    };
+
+public:
+
+  /// Window classes
+  enum WindowClass {
+    ClassNormal,        /// Normal child window
+    ClassGraphic,       /// Graphics child window
+    ClassSpecial,       /// Special child window
+    ClassRoot,          /// Root window
+    ClassShell,         /// Shell window
+    ClassPopup,         /// Popup window
+    ClassToolTip,       /// Tooltip window
+    ClassMain,          /// Main application window
+    ClassDialog,        /// Dialog box window
+    ClassToolBar,       /// Toolbar window
+    ClassSplash,        /// Splash window
+    ClassNotify,        /// Notify window
+    ClassPanel,         /// Panel window
+    ClassDesktop        /// Desktop backdrop window
     };
 
 public:
@@ -191,6 +248,9 @@ public:
   long onMiddleBtnRelease(FXObject*,FXSelector,void*);
   long onRightBtnPress(FXObject*,FXSelector,void*);
   long onRightBtnRelease(FXObject*,FXSelector,void*);
+  long onSpaceBallMotion(FXObject*,FXSelector,void*);
+  long onSpaceBallButtonPress(FXObject*,FXSelector,void*);
+  long onSpaceBallButtonRelease(FXObject*,FXSelector,void*);
   long onBeginDrag(FXObject*,FXSelector,void*);
   long onEndDrag(FXObject*,FXSelector,void*);
   long onDragged(FXObject*,FXSelector,void*);
@@ -233,31 +293,30 @@ public:
   // Message ID's common to most Windows
   enum {
     ID_NONE,
-    ID_HIDE,            // ID_HIDE+FALSE
-    ID_SHOW,            // ID_HIDE+TRUE
+    ID_HIDE,
+    ID_SHOW,
     ID_TOGGLESHOWN,
     ID_LOWER,
     ID_RAISE,
     ID_DELETE,
-    ID_DISABLE,         // ID_DISABLE+FALSE
-    ID_ENABLE,          // ID_DISABLE+TRUE
+    ID_DISABLE,
+    ID_ENABLE,
     ID_TOGGLEENABLED,
-    ID_UNCHECK,         // ID_UNCHECK+FALSE
-    ID_CHECK,           // ID_UNCHECK+TRUE
-    ID_UNKNOWN,         // ID_UNCHECK+MAYBE
+    ID_UNCHECK,
+    ID_CHECK,
+    ID_UNKNOWN,
     ID_UPDATE,
-    ID_AUTOSCROLL,
     ID_TIPTIMER,
-    ID_HSCROLLED,
-    ID_VSCROLLED,
     ID_SETVALUE,
     ID_SETINTVALUE,
+    ID_SETLONGVALUE,
     ID_SETREALVALUE,
     ID_SETSTRINGVALUE,
     ID_SETICONVALUE,
     ID_SETINTRANGE,
     ID_SETREALRANGE,
     ID_GETINTVALUE,
+    ID_GETLONGVALUE,
     ID_GETREALVALUE,
     ID_GETSTRINGVALUE,
     ID_GETICONVALUE,
@@ -291,11 +350,15 @@ public:
 
 public:
 
-  // Common DND type names
+  // Predefined DND type names
+  static const FXchar octetTypeName[];
   static const FXchar deleteTypeName[];
   static const FXchar textTypeName[];
   static const FXchar colorTypeName[];
   static const FXchar urilistTypeName[];
+  static const FXchar utf8TypeName[];
+  static const FXchar utf16TypeName[];
+  static const FXchar actionTypeName[];
 
 public:
 
@@ -329,12 +392,18 @@ public:
   /// Return a pointer to the currently focused child window
   FXWindow* getFocus() const { return focus; }
 
+  /// Get window class
+  virtual WindowClass getWindowClass() const;
+
   /// Change window key
   void setKey(FXuint k){ wk=k; }
 
   /// Return window key
   FXuint getKey() const { return wk; }
 
+  /// Return child window with given window key
+  FXWindow* getChildWithKey(FXuint k) const;
+
   /// Set the message target object for this window
   void setTarget(FXObject *t){ target=t; }
 
@@ -371,10 +440,18 @@ public:
   /// Set this window's y-coordinate, in the parent's coordinate system
   void setY(FXint y);
 
-  /// Set the window width
+  /**
+  * Set the window width; and flag the widget as being in need of
+  * layout by its parent.  This does not immediately update the server-
+  * side representation of the widget.
+  */
   void setWidth(FXint w);
 
-  /// Set the window height
+  /**
+  * Set the window height; and flag the widget as being in need of
+  * layout by its parent.  This does not immediately update the server-
+  * side representation of the widget.
+  */
   void setHeight(FXint h);
 
   /// Set layout hints for this window
@@ -434,14 +511,26 @@ public:
   /// Return the common ancestor of window a and window b
   static FXWindow* commonAncestor(FXWindow* a,FXWindow* b);
 
-  /// Return TRUE if sibling a <= sibling b in list
+  /// Return true if sibling a <= sibling b in list
   static FXbool before(const FXWindow *a,const FXWindow* b);
 
-  /// Return TRUE if sibling a >= sibling b in list
+  /// Return true if sibling a >= sibling b in list
   static FXbool after(const FXWindow *a,const FXWindow* b);
 
-  /// Get number of existing windows
-  static FXint getWindowCount(){ return windowCount; }
+  /// Return compose context
+  FXComposeContext* getComposeContext() const { return composeContext; }
+
+  /// Create compose context
+  void createComposeContext();
+
+  /// Destroy compose context
+  void destroyComposeContext();
+
+  /// Is cursor shown
+  FXbool cursorShown() const;
+
+  /// Show or hide the cursor
+  void showCursor(FXbool flag=true);
 
   /// Set the default cursor for this window
   void setDefaultCursor(FXCursor* cur);
@@ -456,13 +545,10 @@ public:
   FXCursor* getDragCursor() const { return dragCursor; }
 
   /// Return the cursor position and mouse button-state
-  FXint getCursorPosition(FXint& x,FXint& y,FXuint& buttons) const;
+  FXbool getCursorPosition(FXint& x,FXint& y,FXuint& buttons) const;
 
   /// Warp the cursor to the new position
-  FXint setCursorPosition(FXint x,FXint y);
-
-  /// Return true if this window is able to receive mouse and keyboard events
-  FXbool isEnabled() const;
+  FXbool setCursorPosition(FXint x,FXint y);
 
   /// Return true if the window is active
   FXbool isActive() const;
@@ -472,7 +558,7 @@ public:
 
   /// Return true if this window has the focus
   FXbool hasFocus() const;
-  
+
   /// Return true if this window is in focus chain
   FXbool inFocusChain() const;
 
@@ -485,24 +571,33 @@ public:
   /// Notification that focus moved to new child
   virtual void changeFocus(FXWindow *child);
 
-  /**
-  * This changes the default window which responds to the Return
-  * key in a dialog. If enable is TRUE, this window becomes the default
-  * window; when enable is FALSE, this window will be no longer the
-  * default window.  Finally, when enable is MAYBE, the default window
-  * will revert to the initial default window.
-  */
-  virtual void setDefault(FXbool enable=TRUE);
-
   /// Return true if this is the default window
   FXbool isDefault() const;
 
-  /// Make this window the initial default window
-  void setInitial(FXbool enable=TRUE);
+  /**
+  * This changes the default window which responds to the Return
+  * key in a dialog. If the flag is TRUE, this window becomes the default
+  * window; when the flag is FALSE, this window will be no longer the
+  * default window.  Finally, when the flag is MAYBE, the default window
+  * will revert to the initial default window.
+  */
+  virtual void setDefault(FXuchar flag=true);
+
+  /// Find default window among this window's children
+  FXWindow* findDefault() const;
 
   /// Return true if this is the initial default window
   FXbool isInitial() const;
 
+  /// Make this window the initial default window
+  void setInitial(FXbool flag=true);
+
+  /// Find inital default window among this window's children
+  FXWindow* findInitial() const;
+
+  /// Return true if this window is able to receive mouse and keyboard events
+  FXbool isEnabled() const;
+
   /// Enable the window to receive mouse and keyboard events
   virtual void enable();
 
@@ -539,13 +634,25 @@ public:
   /// Lower this window to the bottom of the stacking order
   virtual void lower();
 
-  /// Move this window to the specified position in the parent's coordinates
+  /**
+  * Move the window immediately, in the parent's coordinate system.
+  * Update the server representation as well if the window is realized.
+  * Perform layout of the children when necessary.
+  */
   virtual void move(FXint x,FXint y);
 
-  /// Resize this window to the specified width and height
+  /**
+  * Resize the window to the specified width and height immediately,
+  * updating the server representation as well, if the window was realized.
+  * Perform layout of the children when necessary.
+  */
   virtual void resize(FXint w,FXint h);
 
-  /// Move and resize this window in the parent's coordinates
+  /**
+  * Move and resize the window immediately, in the parent's coordinate system.
+  * Update the server representation as well if the window is realized.
+  * Perform layout of the children when necessary.
+  */
   virtual void position(FXint x,FXint y,FXint w,FXint h);
 
   /// Mark this window's layout as dirty for later layout
@@ -554,7 +661,7 @@ public:
   /// Perform layout immediately
   virtual void layout();
 
-  /// Force a GUI update of this window and its children
+  /// Generate a SEL_UPDATE message for the window and its children
   void forceRefresh();
 
   /// Reparent this window under new father before other
@@ -569,12 +676,15 @@ public:
   /// Mark the entire window to be repainted later
   void update() const;
 
-  /// If marked but not yet painted, paint the given rectangle now
+  /// Process any outstanding repaint messages immediately, for the given rectangle
   void repaint(FXint x,FXint y,FXint w,FXint h) const;
 
-  /// If marked but not yet painted, paint the window now
+  /// Process any outstanding repaint messages immediately
   void repaint() const;
 
+  /// Return true if the window has been grabbed
+  FXbool grabbed() const;
+
   /**
   * Grab the mouse to this window; future mouse events will be
   * reported to this window even while the cursor goes outside of this window
@@ -584,8 +694,8 @@ public:
   /// Release the mouse grab
   void ungrab();
 
-  /// Return true if the window has been grabbed
-  FXbool grabbed() const;
+  /// Return true if active grab is in effect
+  FXbool grabbedKeyboard() const;
 
   /// Grab keyboard device
   void grabKeyboard();
@@ -593,8 +703,8 @@ public:
   /// Ungrab keyboard device
   void ungrabKeyboard();
 
-  /// Return true if active grab is in effect
-  FXbool grabbedKeyboard() const;
+  /// Return true if the window is shown
+  FXbool shown() const;
 
   /// Show this window
   virtual void show();
@@ -602,9 +712,6 @@ public:
   /// Hide this window
   virtual void hide();
 
-  /// Return true if the window is shown
-  FXbool shown() const;
-
   /// Return true if the window is composite
   virtual FXbool isComposite() const;
 
@@ -629,15 +736,15 @@ public:
   /// Release the clipboard
   FXbool releaseClipboard();
 
-  /// Enable this window to receive drops
-  void dropEnable();
-
-  /// Disable this window from receiving drops
-  void dropDisable();
-
   /// Return true if this window is able to receive drops
   FXbool isDropEnabled() const;
 
+  /// Enable this window to receive drops
+  virtual void dropEnable();
+
+  /// Disable this window from receiving drops
+  virtual void dropDisable();
+
   /// Return true if a drag operaion has been initiated from this window
   FXbool isDragging() const;
 
@@ -654,7 +761,7 @@ public:
   * Terminate the drag operation with or without actually dropping the data
   * Returns the action performed by the target
   */
-  FXDragAction endDrag(FXbool drop=TRUE);
+  FXDragAction endDrag(FXbool drop=true);
 
   /// Return true if this window is the target of a drop
   FXbool isDropTarget() const;
@@ -663,7 +770,7 @@ public:
   * When being dragged over, indicate that no further SEL_DND_MOTION messages
   * are required while the cursor is inside the given rectangle
   */
-  void setDragRectangle(FXint x,FXint y,FXint w,FXint h,FXbool wantupdates=TRUE) const;
+  void setDragRectangle(FXint x,FXint y,FXint w,FXint h,FXbool wantupdates=true) const;
 
   /**
   * When being dragged over, indicate we want to receive SEL_DND_MOTION messages
@@ -677,6 +784,19 @@ public:
   /// The target accepted our drop
   FXDragAction didAccept() const;
 
+  /**
+  * Sent by the drop target in response to SEL_DND_DROP.  The drag action
+  * should be the same as the action the drop target reported to the drag
+  * source in reponse to the SEL_DND_MOTION message.
+  * This function notifies the drag source that its part of the drop transaction
+  * is finished, and that it is free to release any resources involved in the
+  * drag operation.
+  * Calling dropFinished() is advisable in cases where the drop target needs
+  * to perform complex processing on the data received from the drag source,
+  * prior to returning from the SEL_DND_DROP message handler.
+  */
+  void dropFinished(FXDragAction action=DRAG_REJECT) const;
+
   /// When being dragged over, inquire the drag types which are being offered
   FXbool inquireDNDTypes(FXDNDOrigin origin,FXDragType*& types,FXuint& numtypes) const;
 
@@ -687,17 +807,27 @@ public:
   FXDragAction inquireDNDAction() const;
 
   /**
-  * Set DND data; the array must be allocated with FXMALLOC and ownership is
-  * transferred to the system
+  * Set DND data; the array must be allocated with allocElms() and ownership is
+  * transferred to the system.
   */
   FXbool setDNDData(FXDNDOrigin origin,FXDragType type,FXuchar* data,FXuint size) const;
 
+  /**
+  * Set DND data from string value.
+  */
+  FXbool setDNDData(FXDNDOrigin origin,FXDragType type,const FXString& string) const;
+
   /**
   * Get DND data; the caller becomes the owner of the array and must free it
-  * with FXFREE
+  * with freeElms().
   */
   FXbool getDNDData(FXDNDOrigin origin,FXDragType type,FXuchar*& data,FXuint& size) const;
 
+  /**
+  * Get DND data into string value.
+  */
+  FXbool getDNDData(FXDNDOrigin origin,FXDragType type,FXString& string) const;
+
   /// Return true if window logically contains the given point
   virtual FXbool contains(FXint parentx,FXint parenty) const;
 
@@ -713,8 +843,19 @@ public:
   /// Get background color
   FXColor getBackColor() const { return backColor; }
 
+  /// Does save-unders
   virtual FXbool doesSaveUnder() const;
 
+  /**
+  * Translate message for localization; using the current FXTranslator,
+  * an attempt is made to translate the given message into the current
+  * language.  An optional hint may be passed to break any ties in case
+  * more than one tranlation is possible for the given message text.
+  * In addition, the name of the widget is passed as context name so
+  * that translations for a single dialog may be grouped together.
+  */
+  virtual const FXchar* tr(const FXchar* text,const FXchar* hint=NULL,FXint count=-1) const FX_FORMAT(2) ;
+
   /// Save window to stream
   virtual void save(FXStream& store) const;
 
