@@ -4,15 +4,20 @@
 
 // FOX version
 #define FOX_MAJOR  1
-#define FOX_MINOR  6
-#define FOX_LEVEL  46
-
+#define FOX_MINOR  7
+#define FOX_LEVEL  51
 
 
 // FOX byte order
 #ifndef FOX_BIGENDIAN
+#if defined(__BIG_ENDIAN__)
+#define FOX_BIGENDIAN 1
+#elif defined(__LITTLE_ENDIAN__)
+#define FOX_BIGENDIAN 0
+#else
 #define FOX_BIGENDIAN 0
 #endif
+#endif
 
 
 #endif
