@@ -3,11 +3,11 @@
 *                        P r e f e r e n c e s   D i a l o g                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2003,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
-* This program is free software; you can redistribute it and/or modify          *
+* This program is free software: you can redistribute it and/or modify          *
 * it under the terms of the GNU General Public License as published by          *
-* the Free Software Foundation; either version 2 of the License, or             *
+* the Free Software Foundation, either version 3 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 * This program is distributed in the hope that it will be useful,               *
@@ -16,10 +16,7 @@
 * GNU General Public License for more details.                                  *
 *                                                                               *
 * You should have received a copy of the GNU General Public License             *
-* along with this program; if not, write to the Free Software                   *
-* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
-*********************************************************************************
-* $Id: Preferences.h,v 1.13 2006/01/22 17:58:15 fox Exp $                       *
+* along with this program.  If not, see <http://www.gnu.org/licenses/>.         *
 ********************************************************************************/
 #ifndef PREFERENCES_H
 #define PREFERENCES_H
@@ -38,54 +35,65 @@ protected:
   FXTextField     *terminal;
   FXCheckButton   *preview;
   FXCheckButton   *blending;
-  FXText          *icondirs;
+  FXCheckButton   *scaling;
+  FXTextField     *icondirs;
   FXList          *extensions;
   FXComboBox      *mimetypes;
-  FXButton        *bigopen;
-  FXButton        *bigclosed;
-  FXButton        *smallopen;
-  FXButton        *smallclosed;
+  FXButton        *iconbutton[4];
   FXCheckButton   *runinterminal;
   FXCheckButton   *changedirectory;
   FXTextField     *description;
   FXTextField     *command;
+  FXString         filedesc;
+  FXString         filemime;
+  FXString         filecommand;
+  FXString         fileicons[4];
+  FXCheckButton   *autosize;
+  FXTextField     *itemspace;
   FXIcon          *brw;
   FXIcon          *pat;
-  FXIcon          *icp;
   FXIcon          *mim;
+  FXIcon          *run;
   FXIcon          *dir;
 private:
   Preferences(){}
   Preferences(const Preferences&);
   Preferences& operator=(const Preferences&);
 public:
+  long onCmdAccept(FXObject*,FXSelector,void*);
+  long onCmdBrowsePaths(FXObject*,FXSelector,void*);
   long onCmdBrowseEditor(FXObject*,FXSelector,void*);
   long onCmdBrowseTerminal(FXObject*,FXSelector,void*);
   long onCmdBrowseCommand(FXObject*,FXSelector,void*);
   long onCmdBrowseIcon(FXObject*,FXSelector,void*);
-
   long onCmdCommand(FXObject*,FXSelector,void*);
-  long onCmdMimeType(FXObject*,FXSelector,void*);
+  long onUpdCommand(FXObject*,FXSelector,void*);
   long onCmdDescription(FXObject*,FXSelector,void*);
-
+  long onUpdDescription(FXObject*,FXSelector,void*);
+  long onCmdMimeType(FXObject*,FXSelector,void*);
+  long onUpdMimeType(FXObject*,FXSelector,void*);
   long onCmdAppendExtension(FXObject*,FXSelector,void*);
+  long onCmdChangeExtension(FXObject*,FXSelector,void*);
   long onCmdRemoveExtension(FXObject*,FXSelector,void*);
   long onCmdSelectExtension(FXObject*,FXSelector,void*);
+  long onCmdDeselectExtension(FXObject*,FXSelector,void*);
   long onUpdSelectExtension(FXObject*,FXSelector,void*);
 public:
   enum{
-    ID_BROWSE_EDITOR=FXDialogBox::ID_LAST,
+    ID_BROWSE_PATHS=FXDialogBox::ID_LAST,
+    ID_BROWSE_EDITOR,
     ID_BROWSE_TERMINAL,
     ID_BROWSE_COMMAND,
+    ID_BROWSE_SMALLICON,
+    ID_BROWSE_BIGICON,
+    ID_BROWSE_SMALLICONOPEN,
+    ID_BROWSE_BIGICONOPEN,
     ID_COMMAND,
     ID_MIMETYPE,
     ID_DESCRIPTION,
-    ID_BROWSE_BIGICON,
-    ID_BROWSE_SMALLICON,
-    ID_BROWSE_BIGICONOPEN,
-    ID_BROWSE_SMALLICONOPEN,
     ID_SELECT_EXTENSION,
     ID_APPEND_EXTENSION,
+    ID_CHANGE_EXTENSION,
     ID_REMOVE_EXTENSION
     };
 public:
@@ -93,8 +101,23 @@ public:
   // Create preferences dialog
   Preferences(PathFinderMain *owner);
 
+  // Populate file bindings and mime types
+  void setupFileBindings();
+
+  // Search iconpath for given name and load the icon
+  FXIcon *createIconFromName(const FXString& name) const;
+
+  // Change icon on button
+  void changeIconButton(const FXString& name,FXint index);
+
+  // Read file extension from registry
+  void readFileExtension(const FXString& ext);
+
+  // Save file extension to registry
+  void writeFileExtension(const FXString& ext);
+
   // Get/set filename patterns
-  void setPatterns(const FXString& pat){ pattern->setText(pat); }
+  void setPatterns(const FXString& ptrn){ pattern->setText(ptrn); }
   FXString getPatterns() const { return pattern->getText(); }
 
   // Get/set text editor
@@ -106,17 +129,29 @@ public:
   FXString getTerminal() const { return terminal->getText(); }
 
   // Set image preview
-  void setPreview(FXbool prev){ preview->setCheck(prev); }
+  void setPreview(FXbool flag){ preview->setCheck(flag); }
   FXbool getPreview() const { return preview->getCheck(); }
 
   // Set image preview
-  void setBlend(FXbool blend){ blending->setCheck(blend); }
-  FXbool getBlend() const { return blending->getCheck(); }
+  void setPreviewBlend(FXbool blend){ blending->setCheck(blend); }
+  FXbool getPreviewBlend() const { return blending->getCheck(); }
+
+  // Set image scale
+  void setPreviewScale(FXbool scale){ scaling->setCheck(scale); }
+  FXbool getPreviewScale() const { return scaling->getCheck(); }
 
   // Get/set icon path
   void setIconPath(const FXString& text){ icondirs->setText(text); }
   FXString getIconPath() const { return icondirs->getText(); }
 
+  // Set autosize
+  void setAutoSize(FXbool flag){ autosize->setCheck(flag); }
+  FXbool getAutoSize() const { return autosize->getCheck(); }
+
+  // Set item space
+  void setItemSpace(FXint s);
+  FXint getItemSpace() const;
+
   // Clean up
   virtual ~Preferences();
   };
