@@ -3,15 +3,12 @@
 *                          M e m o r y   M a p   T e s t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2004,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
-*********************************************************************************
-* $Id: memmap.cpp,v 1.5 2006/01/22 17:59:02 fox Exp $                           *
+* Copyright (C) 2004,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 ********************************************************************************/
 #include "fx.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "FXMemMap.h"
 
 /*
   Notes:
@@ -75,7 +72,7 @@ int main(int argc,char** argv){
   filename=argv[3];
 
   // Show process id
-  fprintf(stderr,"Process id=%d\n",fxgetpid());
+  fprintf(stderr,"Process id=%d\n",FXProcess::current());
 
   // Test reading
   if(action==TEST_READ){
@@ -85,9 +82,9 @@ int main(int argc,char** argv){
     getchar();
 
     // Map
-    base=(char*)map.mapFile(filename,offset,length,FXMemMap::READ,FXMemMap::SHAR);
+    base=(char*)map.openMap(filename,offset,length,FXIO::Reading,FXIO::AllReadWrite);
     if(base==NULL){
-      fprintf(stderr,"mapFile returned NULL\n");
+      fprintf(stderr,"openMap returned NULL\n");
       exit(1);
       }
 
@@ -118,9 +115,9 @@ int main(int argc,char** argv){
     getchar();
 
     // Map
-    base=(char*)map.mapFile(filename,offset,length,FXMemMap::READ|FXMemMap::WRITE|FXMemMap::TRUNC,FXMemMap::SHAR);
+    base=(char*)map.openMap(filename,offset,length,FXIO::Writing,FXIO::AllReadWrite);
     if(base==NULL){
-      fprintf(stderr,"mapFile returned NULL\n");
+      fprintf(stderr,"openMap returned NULL\n");
       exit(1);
       }
 
