@@ -3,9 +3,7 @@
 *                                 Test Tab Book                                 *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997 by Jeroen van der Zijp.   All Rights Reserved.             *
-*********************************************************************************
-* $Id: tabbook.cpp,v 1.23 2006/02/06 03:06:51 fox Exp $                         *
+* Copyright (C) 1997,2015 by Jeroen van der Zijp.   All Rights Reserved.        *
 ********************************************************************************/
 #include "fx.h"
 
@@ -57,8 +55,8 @@ public:
     ID_TABS_RIGHT,
     ID_HIDESHOW,
     ID_PANEL,
-	ID_PACK_UNIFORM_WIDTH,
-	ID_PACK_NON_UNIFORM_WIDTH,
+    ID_PACK_UNIFORM_WIDTH,
+    ID_PACK_NON_UNIFORM_WIDTH,
     };
 public:
   TabBookWindow(FXApp* a);
@@ -200,19 +198,17 @@ long TabBookWindow::onCmdTabOrient(FXObject*,FXSelector sel,void*){
   }
 
 // Calculate tab header widths based on largest tab label string
-long TabBookWindow::onCmdPackUniformWidth(FXObject*,FXSelector sel,void*){
-  FXuint sid=FXSELID(sel);
-  FXuint packing_hints = tabbook->getPackingHints();
-  packing_hints |= PACK_UNIFORM_WIDTH;
+long TabBookWindow::onCmdPackUniformWidth(FXObject*,FXSelector,void*){
+  FXuint packing_hints=tabbook->getPackingHints();
+  packing_hints|=PACK_UNIFORM_WIDTH;
   tabbook->setPackingHints(packing_hints);
   return 1;
   }
 
 // Calculate tab header width individually for each tab label string
-long TabBookWindow::onCmdPackNonUniformWidth(FXObject*,FXSelector sel,void*){
-  FXuint sid=FXSELID(sel);
-  FXuint packing_hints = tabbook->getPackingHints();
-  packing_hints &= ~PACK_UNIFORM_WIDTH;
+long TabBookWindow::onCmdPackNonUniformWidth(FXObject*,FXSelector,void*){
+  FXuint packing_hints=tabbook->getPackingHints();
+  packing_hints&=~PACK_UNIFORM_WIDTH;
   tabbook->setPackingHints(packing_hints);
   return 1;
   }
